@@ -6,6 +6,7 @@ use serde::{Deserialize, Serialize};
 use url::Url;
 
 use pep440_rs::{VersionSpecifiers, VersionSpecifiersParseError};
+use pep508_rs::VerbatimUrl;
 use pypi_types::{CoreMetadata, HashDigest, Yanked};
 
 /// Error converting [`pypi_types::File`] to [`distribution_type::File`].
@@ -149,6 +150,8 @@ impl Display for FileLocation {
     Clone,
     PartialEq,
     Eq,
+    PartialOrd,
+    Ord,
     Hash,
     Serialize,
     Deserialize,
@@ -166,6 +169,14 @@ impl UrlString {
         // This conversion can never fail as the only way to construct a `UrlString` is from a `Url`.
         Url::from_str(&self.0).unwrap()
     }
+
+    /// Return the [`UrlString`] with any query parameters and fragments removed.
+    pub fn base(&self) -> &str {
+        self.as_ref()
+            .split_once(['#', '?'])
+            .map(|(path, _)| path)
+            .unwrap_or(self.as_ref())
+    }
 }
 
 impl AsRef<str> for UrlString {
@@ -180,6 +191,24 @@ impl From<Url> for UrlString {
     }
 }
 
+impl From<&Url> for UrlString {
+    fn from(value: &Url) -> Self {
+        UrlString(value.to_string())
+    }
+}
+
+impl From<VerbatimUrl> for UrlString {
+    fn from(value: VerbatimUrl) -> Self {
+        UrlString(value.raw().to_string())
+    }
+}
+
+impl From<&VerbatimUrl> for UrlString {
+    fn from(value: &VerbatimUrl) -> Self {
+        UrlString(value.raw().to_string())
+    }
+}
+
 impl From<UrlString> for String {
     fn from(value: UrlString) -> Self {
         value.0
