@@ -39,9 +39,10 @@ use url::Url;
 
 use cursor::Cursor;
 pub use marker::{
-    ExtraOperator, MarkerEnvironment, MarkerEnvironmentBuilder, MarkerExpression, MarkerOperator,
-    MarkerTree, MarkerValue, MarkerValueString, MarkerValueVersion, MarkerWarningKind,
-    StringVersion,
+    ContainsMarkerTree, ExtraMarkerTree, ExtraOperator, InMarkerTree, MarkerEnvironment,
+    MarkerEnvironmentBuilder, MarkerExpression, MarkerOperator, MarkerTree, MarkerTreeContents,
+    MarkerTreeKind, MarkerValue, MarkerValueString, MarkerValueVersion, MarkerWarningKind,
+    StringMarkerTree, StringVersion, VersionMarkerTree,
 };
 pub use origin::RequirementOrigin;
 #[cfg(feature = "pyo3")]
@@ -189,7 +190,7 @@ impl<T: Pep508Url + Display> Display for Requirement<T> {
                 }
             }
         }
-        if let Some(marker) = &self.marker {
+        if let Some(marker) = self.marker.as_ref().and_then(MarkerTree::contents) {
             write!(f, " ; {marker}")?;
         }
         Ok(())
@@ -255,7 +256,10 @@ impl PyRequirement {
     /// `requests [security,tests] >= 2.8.1, == 2.8.* ; python_version > "3.8"`
     #[getter]
     pub fn marker(&self) -> Option<String> {
-        self.marker.as_ref().map(ToString::to_string)
+        self.marker
+            .as_ref()
+            .and_then(MarkerTree::contents)
+            .map(|marker| marker.to_string())
     }
 
     /// Parses a PEP 440 string
@@ -416,18 +420,20 @@ impl<T: Pep508Url> Requirement<T> {
     #[must_use]
     pub fn with_extra_marker(self, extra: &ExtraName) -> Self {
         let marker = match self.marker {
-            Some(expression) => MarkerTree::And(vec![
-                expression,
-                MarkerTree::Expression(MarkerExpression::Extra {
+            Some(mut marker) => {
+                let extra = MarkerTree::expression(MarkerExpression::Extra {
                     operator: ExtraOperator::Equal,
                     name: extra.clone(),
-                }),
-            ]),
-            None => MarkerTree::Expression(MarkerExpression::Extra {
+                });
+                marker.and(extra);
+                marker
+            }
+            None => MarkerTree::expression(MarkerExpression::Extra {
                 operator: ExtraOperator::Equal,
                 name: extra.clone(),
             }),
         };
+
         Self {
             marker: Some(marker),
             ..self
@@ -693,6 +699,11 @@ fn looks_like_unnamed_requirement(cursor: &mut Cursor) -> bool {
         return true;
     }
 
+    // Ex) `foo/bar`
+    if expanded.contains('/') || expanded.contains('\\') {
+        return true;
+    }
+
     false
 }
 
@@ -1010,7 +1021,7 @@ fn parse_pep508_requirement<T: Pep508Url>(
             // a package name. pip supports this in `requirements.txt`, but it doesn't adhere to
             // the PEP 508 grammar.
             let mut clone = cursor.clone().at(start);
-            return if parse_url::<T>(&mut clone, working_dir).is_ok() {
+            return if looks_like_unnamed_requirement(&mut clone) {
                 Err(Pep508Error {
                     message: Pep508ErrorSource::UnsupportedRequirement("URL requirement must be preceded by a package name. Add the name of the package before the URL (e.g., `package_name @ https://...`).".to_string()),
                     start,
@@ -1038,7 +1049,7 @@ fn parse_pep508_requirement<T: Pep508Url>(
     let marker = if cursor.peek_char() == Some(';') {
         // Skip past the semicolon
         cursor.next();
-        Some(marker::parse::parse_markers_cursor(cursor, reporter)?)
+        marker::parse::parse_markers_cursor(cursor, reporter)?
     } else {
         None
     };
@@ -1118,10 +1129,10 @@ mod tests {
     use uv_normalize::{ExtraName, InvalidNameError, PackageName};
 
     use crate::cursor::Cursor;
-    use crate::marker::{
-        parse, MarkerExpression, MarkerOperator, MarkerTree, MarkerValueString, MarkerValueVersion,
+    use crate::marker::{parse, MarkerExpression, MarkerTree, MarkerValueVersion};
+    use crate::{
+        MarkerOperator, MarkerValueString, Requirement, TracingReporter, VerbatimUrl, VersionOrUrl,
     };
-    use crate::{Requirement, TracingReporter, VerbatimUrl, VersionOrUrl};
 
     fn parse_pep508_err(input: &str) -> String {
         Requirement::<VerbatimUrl>::from_str(input)
@@ -1211,7 +1222,7 @@ mod tests {
                 .into_iter()
                 .collect(),
             )),
-            marker: Some(MarkerTree::Expression(MarkerExpression::Version {
+            marker: Some(MarkerTree::expression(MarkerExpression::Version {
                 key: MarkerValueVersion::PythonVersion,
                 specifier: VersionSpecifier::from_pattern(
                     pep440_rs::Operator::LessThan,
@@ -1458,37 +1469,38 @@ mod tests {
             &mut Cursor::new(marker),
             &mut TracingReporter,
         )
+        .unwrap()
         .unwrap();
-        let expected = MarkerTree::And(vec![
-            MarkerTree::Expression(MarkerExpression::Version {
-                key: MarkerValueVersion::PythonVersion,
-                specifier: VersionSpecifier::from_pattern(
-                    pep440_rs::Operator::Equal,
-                    "2.7".parse().unwrap(),
-                )
-                .unwrap(),
-            }),
-            MarkerTree::Or(vec![
-                MarkerTree::Expression(MarkerExpression::String {
-                    key: MarkerValueString::SysPlatform,
-                    operator: MarkerOperator::Equal,
-                    value: "win32".to_string(),
-                }),
-                MarkerTree::And(vec![
-                    MarkerTree::Expression(MarkerExpression::String {
-                        key: MarkerValueString::OsName,
-                        operator: MarkerOperator::Equal,
-                        value: "linux".to_string(),
-                    }),
-                    MarkerTree::Expression(MarkerExpression::String {
-                        key: MarkerValueString::ImplementationName,
-                        operator: MarkerOperator::Equal,
-                        value: "cpython".to_string(),
-                    }),
-                ]),
-            ]),
-        ]);
-        assert_eq!(expected, actual);
+
+        let mut a = MarkerTree::expression(MarkerExpression::Version {
+            key: MarkerValueVersion::PythonVersion,
+            specifier: VersionSpecifier::from_pattern(
+                pep440_rs::Operator::Equal,
+                "2.7".parse().unwrap(),
+            )
+            .unwrap(),
+        });
+        let mut b = MarkerTree::expression(MarkerExpression::String {
+            key: MarkerValueString::SysPlatform,
+            operator: MarkerOperator::Equal,
+            value: "win32".to_string(),
+        });
+        let mut c = MarkerTree::expression(MarkerExpression::String {
+            key: MarkerValueString::OsName,
+            operator: MarkerOperator::Equal,
+            value: "linux".to_string(),
+        });
+        let d = MarkerTree::expression(MarkerExpression::String {
+            key: MarkerValueString::ImplementationName,
+            operator: MarkerOperator::Equal,
+            value: "cpython".to_string(),
+        });
+
+        c.and(d);
+        b.or(c);
+        a.and(b);
+
+        assert_eq!(a, actual);
     }
 
     #[test]
