@@ -2,6 +2,8 @@ use std::fmt::{Display, Formatter};
 use std::path::{Path, PathBuf};
 use std::str::FromStr;
 
+use distribution_filename::DistExtension;
+use serde::Serialize;
 use thiserror::Error;
 use url::Url;
 
@@ -12,7 +14,8 @@ use uv_git::{GitReference, GitSha, GitUrl};
 use uv_normalize::{ExtraName, PackageName};
 
 use crate::{
-    ParsedArchiveUrl, ParsedDirectoryUrl, ParsedGitUrl, ParsedPathUrl, ParsedUrl, VerbatimParsedUrl,
+    ParsedArchiveUrl, ParsedDirectoryUrl, ParsedGitUrl, ParsedPathUrl, ParsedUrl, ParsedUrlError,
+    VerbatimParsedUrl,
 };
 
 #[derive(Debug, Error)]
@@ -20,6 +23,8 @@ pub enum RequirementError {
     #[error(transparent)]
     VerbatimUrlError(#[from] pep508_rs::VerbatimUrlError),
     #[error(transparent)]
+    ParsedUrlError(#[from] ParsedUrlError),
+    #[error(transparent)]
     UrlParseError(#[from] url::ParseError),
     #[error(transparent)]
     OidParseError(#[from] uv_git::OidParseError),
@@ -34,6 +39,11 @@ pub struct Requirement {
     pub name: PackageName,
     #[serde(skip_serializing_if = "Vec::is_empty", default)]
     pub extras: Vec<ExtraName>,
+    #[serde(
+        skip_serializing_if = "marker_is_empty",
+        serialize_with = "serialize_marker",
+        default
+    )]
     pub marker: Option<MarkerTree>,
     #[serde(flatten)]
     pub source: RequirementSource,
@@ -41,6 +51,17 @@ pub struct Requirement {
     pub origin: Option<RequirementOrigin>,
 }
 
+fn marker_is_empty(marker: &Option<MarkerTree>) -> bool {
+    marker.as_ref().and_then(MarkerTree::contents).is_none()
+}
+
+fn serialize_marker<S>(marker: &Option<MarkerTree>, s: S) -> Result<S::Ok, S::Error>
+where
+    S: serde::Serializer,
+{
+    marker.as_ref().unwrap().contents().unwrap().serialize(s)
+}
+
 impl Requirement {
     /// Returns whether the markers apply for the given environment.
     ///
@@ -95,13 +116,15 @@ impl From<Requirement> for pep508_rs::Requirement<VerbatimParsedUrl> {
                     Some(VersionOrUrl::VersionSpecifier(specifier))
                 }
                 RequirementSource::Url {
-                    subdirectory,
                     location,
+                    subdirectory,
+                    ext,
                     url,
                 } => Some(VersionOrUrl::Url(VerbatimParsedUrl {
                     parsed_url: ParsedUrl::Archive(ParsedArchiveUrl {
                         url: location,
                         subdirectory,
+                        ext,
                     }),
                     verbatim: url,
                 })),
@@ -128,12 +151,14 @@ impl From<Requirement> for pep508_rs::Requirement<VerbatimParsedUrl> {
                 RequirementSource::Path {
                     install_path,
                     lock_path,
+                    ext,
                     url,
                 } => Some(VersionOrUrl::Url(VerbatimParsedUrl {
                     parsed_url: ParsedUrl::Path(ParsedPathUrl {
                         url: url.to_url(),
                         install_path,
                         lock_path,
+                        ext,
                     }),
                     verbatim: url,
                 })),
@@ -231,7 +256,7 @@ impl Display for Requirement {
                 write!(f, " @ {url}")?;
             }
         }
-        if let Some(marker) = &self.marker {
+        if let Some(marker) = self.marker.as_ref().and_then(MarkerTree::contents) {
             write!(f, " ; {marker}")?;
         }
         Ok(())
@@ -259,11 +284,13 @@ pub enum RequirementSource {
     /// e.g. `foo @ https://example.org/foo-1.0-py3-none-any.whl`, or a source distribution,
     /// e.g.`foo @ https://example.org/foo-1.0.zip`.
     Url {
+        /// The remote location of the archive file, without subdirectory fragment.
+        location: Url,
         /// For source distributions, the path to the distribution if it is not in the archive
         /// root.
         subdirectory: Option<PathBuf>,
-        /// The remote location of the archive file, without subdirectory fragment.
-        location: Url,
+        /// The file extension, e.g. `tar.gz`, `zip`, etc.
+        ext: DistExtension,
         /// The PEP 508 style URL in the format
         /// `<scheme>://<domain>/<path>#subdirectory=<subdirectory>`.
         url: VerbatimUrl,
@@ -292,6 +319,8 @@ pub enum RequirementSource {
         /// which we use for locking. Unlike `given` on the verbatim URL all environment variables
         /// are resolved, and unlike the install path, we did not yet join it on the base directory.
         lock_path: PathBuf,
+        /// The file extension, e.g. `tar.gz`, `zip`, etc.
+        ext: DistExtension,
         /// The PEP 508 style URL in the format
         /// `file:///<path>#subdirectory=<subdirectory>`.
         url: VerbatimUrl,
@@ -321,6 +350,7 @@ impl RequirementSource {
             ParsedUrl::Path(local_file) => RequirementSource::Path {
                 install_path: local_file.install_path.clone(),
                 lock_path: local_file.lock_path.clone(),
+                ext: local_file.ext,
                 url,
             },
             ParsedUrl::Directory(directory) => RequirementSource::Directory {
@@ -340,6 +370,7 @@ impl RequirementSource {
                 url,
                 location: archive.url,
                 subdirectory: archive.subdirectory,
+                ext: archive.ext,
             },
         }
     }
@@ -347,7 +378,7 @@ impl RequirementSource {
     /// Construct a [`RequirementSource`] for a URL source, given a URL parsed into components.
     pub fn from_verbatim_parsed_url(parsed_url: ParsedUrl) -> Self {
         let verbatim_url = VerbatimUrl::from_url(Url::from(parsed_url.clone()));
-        RequirementSource::from_parsed_url(parsed_url, verbatim_url)
+        Self::from_parsed_url(parsed_url, verbatim_url)
     }
 
     /// Convert the source to a [`VerbatimParsedUrl`], if it's a URL source.
@@ -355,24 +386,28 @@ impl RequirementSource {
         match &self {
             Self::Registry { .. } => None,
             Self::Url {
-                subdirectory,
                 location,
+                subdirectory,
+                ext,
                 url,
             } => Some(VerbatimParsedUrl {
                 parsed_url: ParsedUrl::Archive(ParsedArchiveUrl::from_source(
                     location.clone(),
                     subdirectory.clone(),
+                    *ext,
                 )),
                 verbatim: url.clone(),
             }),
             Self::Path {
                 install_path,
                 lock_path,
+                ext,
                 url,
             } => Some(VerbatimParsedUrl {
                 parsed_url: ParsedUrl::Path(ParsedPathUrl::from_source(
                     install_path.clone(),
                     lock_path.clone(),
+                    *ext,
                     url.to_url(),
                 )),
                 verbatim: url.clone(),
@@ -431,6 +466,17 @@ impl RequirementSource {
     pub fn is_editable(&self) -> bool {
         matches!(self, Self::Directory { editable: true, .. })
     }
+
+    /// If the source is the registry, return the version specifiers
+    pub fn version_specifiers(&self) -> Option<&VersionSpecifiers> {
+        match self {
+            RequirementSource::Registry { specifier, .. } => Some(specifier),
+            RequirementSource::Url { .. }
+            | RequirementSource::Git { .. }
+            | RequirementSource::Path { .. }
+            | RequirementSource::Directory { .. } => None,
+        }
+    }
 }
 
 impl Display for RequirementSource {
@@ -504,6 +550,7 @@ impl From<RequirementSource> for RequirementSourceWire {
             RequirementSource::Url {
                 subdirectory,
                 location,
+                ext: _,
                 url: _,
             } => Self::Direct {
                 url: location,
@@ -564,6 +611,7 @@ impl From<RequirementSource> for RequirementSourceWire {
             RequirementSource::Path {
                 install_path,
                 lock_path: _,
+                ext: _,
                 url: _,
             } => Self::Path {
                 path: PortablePathBuf::from(install_path),
@@ -626,13 +674,17 @@ impl TryFrom<RequirementSourceWire> for RequirementSource {
             }
             RequirementSourceWire::Direct { url, subdirectory } => Ok(Self::Url {
                 url: VerbatimUrl::from_url(url.clone()),
-                subdirectory: subdirectory.map(PathBuf::from),
                 location: url.clone(),
+                subdirectory: subdirectory.map(PathBuf::from),
+                ext: DistExtension::from_path(url.path())
+                    .map_err(|err| ParsedUrlError::MissingExtensionUrl(url.to_string(), err))?,
             }),
             RequirementSourceWire::Path { path } => {
                 let path = PathBuf::from(path);
                 Ok(Self::Path {
                     url: VerbatimUrl::from_path(path.as_path())?,
+                    ext: DistExtension::from_path(path.as_path())
+                        .map_err(|err| ParsedUrlError::MissingExtensionPath(path.clone(), err))?,
                     install_path: path.clone(),
                     lock_path: path,
                 })
