@@ -453,7 +453,7 @@ impl RegistryClient {
                 .await?
             }
             BuiltDist::Path(wheel) => {
-                let file = fs_err::tokio::File::open(&wheel.path)
+                let file = fs_err::tokio::File::open(&wheel.install_path)
                     .await
                     .map_err(ErrorKind::Io)?;
                 let reader = tokio::io::BufReader::new(file);
@@ -718,30 +718,32 @@ impl SimpleMetadata {
 
         // Group the distributions by version and kind
         for file in files {
-            if let Some(filename) =
+            let Some(filename) =
                 DistFilename::try_from_filename(file.filename.as_str(), package_name)
-            {
-                let version = match filename {
-                    DistFilename::SourceDistFilename(ref inner) => &inner.version,
-                    DistFilename::WheelFilename(ref inner) => &inner.version,
-                };
-                let file = match File::try_from(file, base) {
-                    Ok(file) => file,
-                    Err(err) => {
-                        // Ignore files with unparsable version specifiers.
-                        warn!("Skipping file for {package_name}: {err}");
-                        continue;
-                    }
-                };
-                match map.entry(version.clone()) {
-                    std::collections::btree_map::Entry::Occupied(mut entry) => {
-                        entry.get_mut().push(filename, file);
-                    }
-                    std::collections::btree_map::Entry::Vacant(entry) => {
-                        let mut files = VersionFiles::default();
-                        files.push(filename, file);
-                        entry.insert(files);
-                    }
+            else {
+                warn!("Skipping file for {package_name}: {}", file.filename);
+                continue;
+            };
+            let version = match filename {
+                DistFilename::SourceDistFilename(ref inner) => &inner.version,
+                DistFilename::WheelFilename(ref inner) => &inner.version,
+            };
+            let file = match File::try_from(file, base) {
+                Ok(file) => file,
+                Err(err) => {
+                    // Ignore files with unparsable version specifiers.
+                    warn!("Skipping file for {package_name}: {err}");
+                    continue;
+                }
+            };
+            match map.entry(version.clone()) {
+                std::collections::btree_map::Entry::Occupied(mut entry) => {
+                    entry.get_mut().push(filename, file);
+                }
+                std::collections::btree_map::Entry::Vacant(entry) => {
+                    let mut files = VersionFiles::default();
+                    files.push(filename, file);
+                    entry.insert(files);
                 }
             }
         }
