@@ -2,7 +2,7 @@
 
 use anyhow::Result;
 
-use crate::{generate_json_schema, generate_options_reference};
+use crate::{generate_cli_reference, generate_json_schema, generate_options_reference};
 
 #[derive(clap::Args)]
 pub(crate) struct Args {
@@ -26,5 +26,6 @@ pub(crate) enum Mode {
 pub(crate) fn main(args: &Args) -> Result<()> {
     generate_json_schema::main(&generate_json_schema::Args { mode: args.mode })?;
     generate_options_reference::main(&generate_options_reference::Args { mode: args.mode })?;
+    generate_cli_reference::main(&generate_cli_reference::Args { mode: args.mode })?;
     Ok(())
 }
