@@ -5,15 +5,15 @@ use std::pin::Pin;
 use std::str::FromStr;
 use std::task::{Context, Poll};
 
+use distribution_filename::{ExtensionError, SourceDistExtension};
 use futures::TryStreamExt;
 use owo_colors::OwoColorize;
+use pypi_types::{HashAlgorithm, HashDigest};
 use thiserror::Error;
 use tokio::io::{AsyncRead, ReadBuf};
 use tokio_util::compat::FuturesAsyncReadCompatExt;
 use tracing::{debug, instrument};
 use url::Url;
-
-use pypi_types::{HashAlgorithm, HashDigest};
 use uv_cache::Cache;
 use uv_client::WrappedReqwestError;
 use uv_extract::hash::Hasher;
@@ -32,14 +32,16 @@ pub enum Error {
     Io(#[from] io::Error),
     #[error(transparent)]
     ImplementationError(#[from] ImplementationError),
+    #[error("Expected download URL (`{0}`) to end in a supported file extension: {1}")]
+    MissingExtension(String, ExtensionError),
     #[error("Invalid Python version: {0}")]
     InvalidPythonVersion(String),
     #[error("Invalid request key (too many parts): {0}")]
     TooManyParts(String),
-    #[error("Download failed")]
+    #[error(transparent)]
     NetworkError(#[from] WrappedReqwestError),
-    #[error("Download failed")]
-    NetworkMiddlewareError(#[source] anyhow::Error),
+    #[error(transparent)]
+    NetworkMiddlewareError(#[from] anyhow::Error),
     #[error("Failed to extract archive: {0}")]
     ExtractError(String, #[source] uv_extract::Error),
     #[error("Failed to hash installation")]
@@ -70,6 +72,10 @@ pub enum Error {
     InvalidRequestPlatform(#[from] platform::Error),
     #[error("No download found for request: {}", _0.green())]
     NoDownloadFound(PythonDownloadRequest),
+    #[error(
+        "A mirror was provided via `{0}`, but the URL does not match the expected format: {0}"
+    )]
+    Mirror(&'static str, &'static str),
 }
 
 #[derive(Debug, PartialEq)]
@@ -410,7 +416,7 @@ impl ManagedPythonDownload {
         cache: &Cache,
         reporter: Option<&dyn Reporter>,
     ) -> Result<DownloadResult, Error> {
-        let url = Url::parse(self.url)?;
+        let url = self.download_url()?;
         let path = parent_path.join(self.key().to_string());
 
         // If it already exists, return it
@@ -419,6 +425,8 @@ impl ManagedPythonDownload {
         }
 
         let filename = url.path_segments().unwrap().last().unwrap();
+        let ext = SourceDistExtension::from_path(filename)
+            .map_err(|err| Error::MissingExtension(url.to_string(), err))?;
         let response = client.get(url.clone()).send().await?;
 
         // Ensure the request was successful.
@@ -433,8 +441,8 @@ impl ManagedPythonDownload {
         let temp_dir = tempfile::tempdir_in(cache.root()).map_err(Error::DownloadDirError)?;
 
         debug!(
-            "Downloading {url} to temporary location {}",
-            temp_dir.path().display()
+            "Downloading {url} to temporary location: {}",
+            temp_dir.path().simplified().display()
         );
 
         let stream = response
@@ -454,12 +462,12 @@ impl ManagedPythonDownload {
         match progress {
             Some((&reporter, progress)) => {
                 let mut reader = ProgressReader::new(&mut hasher, progress, reporter);
-                uv_extract::stream::archive(&mut reader, filename, temp_dir.path())
+                uv_extract::stream::archive(&mut reader, ext, temp_dir.path())
                     .await
                     .map_err(|err| Error::ExtractError(filename.to_string(), err))?;
             }
             None => {
-                uv_extract::stream::archive(&mut hasher, filename, temp_dir.path())
+                uv_extract::stream::archive(&mut hasher, ext, temp_dir.path())
                     .await
                     .map_err(|err| Error::ExtractError(filename.to_string(), err))?;
             }
@@ -525,6 +533,41 @@ impl ManagedPythonDownload {
     pub fn python_version(&self) -> PythonVersion {
         self.key.version()
     }
+
+    /// Return the [`Url`] to use when downloading the distribution. If a mirror is set via the
+    /// appropriate environment variable, use it instead.
+    fn download_url(&self) -> Result<Url, Error> {
+        match self.key.implementation {
+            LenientImplementationName::Known(ImplementationName::CPython) => {
+                if let Ok(mirror) = std::env::var("UV_PYTHON_INSTALL_MIRROR") {
+                    let Some(suffix) = self.url.strip_prefix(
+                        "https://github.com/indygreg/python-build-standalone/releases/download/",
+                    ) else {
+                        return Err(Error::Mirror("UV_PYTHON_INSTALL_MIRROR", self.url));
+                    };
+                    return Ok(Url::parse(
+                        format!("{}/{}", mirror.trim_end_matches('/'), suffix).as_str(),
+                    )?);
+                }
+            }
+
+            LenientImplementationName::Known(ImplementationName::PyPy) => {
+                if let Ok(mirror) = std::env::var("UV_PYPY_INSTALL_MIRROR") {
+                    let Some(suffix) = self.url.strip_prefix("https://downloads.python.org/pypy/")
+                    else {
+                        return Err(Error::Mirror("UV_PYPY_INSTALL_MIRROR", self.url));
+                    };
+                    return Ok(Url::parse(
+                        format!("{}/{}", mirror.trim_end_matches('/'), suffix).as_str(),
+                    )?);
+                }
+            }
+
+            _ => {}
+        }
+
+        Ok(Url::parse(self.url)?)
+    }
 }
 
 impl From<reqwest::Error> for Error {
