@@ -106,7 +106,8 @@ impl<'a, Context: BuildContext> SourceTreeResolver<'a, Context> {
                 origin: Some(origin.clone()),
                 marker: requirement
                     .marker
-                    .and_then(|marker| marker.simplify_extras(extras)),
+                    .map(|marker| marker.simplify_extras(extras))
+                    .filter(|marker| !marker.is_true()),
                 ..requirement
             })
             .collect();
@@ -129,7 +130,8 @@ impl<'a, Context: BuildContext> SourceTreeResolver<'a, Context> {
                 requirement.marker = requirement
                     .marker
                     .take()
-                    .and_then(|marker| marker.simplify_extras(&recursive.extras));
+                    .map(|marker| marker.simplify_extras(&recursive.extras))
+                    .filter(|marker| !marker.is_true());
             }
         }
 
