@@ -7,7 +7,7 @@ use rustc_hash::FxHashMap;
 
 use distribution_types::{BuiltDist, IndexLocations, InstalledDist, SourceDist};
 use pep440_rs::Version;
-use pep508_rs::{MarkerTree, Requirement};
+use pep508_rs::MarkerTree;
 use uv_normalize::PackageName;
 
 use crate::candidate_selector::CandidateSelector;
@@ -19,9 +19,6 @@ use crate::resolver::{IncompletePackage, ResolverMarkers, UnavailablePackage, Un
 
 #[derive(Debug, thiserror::Error)]
 pub enum ResolveError {
-    #[error("Failed to find a version of `{0}` that satisfies the requirement")]
-    NotFound(Requirement),
-
     #[error(transparent)]
     Client(#[from] uv_client::Error),
 
@@ -49,7 +46,7 @@ pub enum ResolveError {
     #[error("Requirements contain conflicting URLs for package `{0}`:\n- {}", _1.join("\n- "))]
     ConflictingUrlsUniversal(PackageName, Vec<String>),
 
-    #[error("Requirements contain conflicting URLs for package `{package_name}` in split `{fork_markers}`:\n- {}", urls.join("\n- "))]
+    #[error("Requirements contain conflicting URLs for package `{package_name}` in split `{fork_markers:?}`:\n- {}", urls.join("\n- "))]
     ConflictingUrlsFork {
         package_name: PackageName,
         urls: Vec<String>,
@@ -65,6 +62,9 @@ pub enum ResolveError {
     #[error(transparent)]
     DistributionType(#[from] distribution_types::Error),
 
+    #[error(transparent)]
+    ParsedUrl(#[from] pypi_types::ParsedUrlError),
+
     #[error("Failed to download `{0}`")]
     Fetch(Box<BuiltDist>, #[source] uv_distribution::Error),
 
@@ -134,7 +134,7 @@ impl NoSolutionError {
                 "No solution found when resolving dependencies:".to_string()
             }
             ResolverMarkers::Fork(markers) => {
-                format!("No solution found when resolving dependencies for split ({markers}):")
+                format!("No solution found when resolving dependencies for split ({markers:?}):")
             }
         }
     }
