@@ -89,7 +89,11 @@ impl RequirementsTxtDist {
                     }
                 };
                 if let Some(given) = given {
-                    return if let Some(markers) = self.markers.as_ref().filter(|_| include_markers)
+                    return if let Some(markers) = self
+                        .markers
+                        .as_ref()
+                        .filter(|_| include_markers)
+                        .and_then(MarkerTree::contents)
                     {
                         Cow::Owned(format!("{given} ; {markers}"))
                     } else {
@@ -100,7 +104,12 @@ impl RequirementsTxtDist {
         }
 
         if self.extras.is_empty() || !include_extras {
-            if let Some(markers) = self.markers.as_ref().filter(|_| include_markers) {
+            if let Some(markers) = self
+                .markers
+                .as_ref()
+                .filter(|_| include_markers)
+                .and_then(MarkerTree::contents)
+            {
                 Cow::Owned(format!("{} ; {}", self.dist.verbatim(), markers))
             } else {
                 self.dist.verbatim()
@@ -109,7 +118,12 @@ impl RequirementsTxtDist {
             let mut extras = self.extras.clone();
             extras.sort_unstable();
             extras.dedup();
-            if let Some(markers) = self.markers.as_ref().filter(|_| include_markers) {
+            if let Some(markers) = self
+                .markers
+                .as_ref()
+                .filter(|_| include_markers)
+                .and_then(MarkerTree::contents)
+            {
                 Cow::Owned(format!(
                     "{}[{}]{} ; {}",
                     self.name(),
