@@ -7,9 +7,9 @@ use distribution_types::{CachedDist, IndexLocations, InstalledDist, Resolution,
 use pep508_rs::PackageName;
 use pypi_types::Requirement;
 use uv_cache::Cache;
-use uv_configuration::{BuildKind, BuildOptions};
+use uv_configuration::{BuildKind, BuildOptions, SourceStrategy};
 use uv_git::GitResolver;
-use uv_python::{Interpreter, PythonEnvironment};
+use uv_python::PythonEnvironment;
 
 ///  Avoids cyclic crate dependencies between resolver, installer and builder.
 ///
@@ -57,16 +57,15 @@ pub trait BuildContext {
     /// Return a reference to the Git resolver.
     fn git(&self) -> &GitResolver;
 
-    /// All (potentially nested) source distribution builds use the same base python and can reuse
-    /// it's metadata (e.g. wheel compatibility tags).
-    fn interpreter(&self) -> &Interpreter;
-
     /// Whether source distribution building or pre-built wheels is disabled.
     ///
     /// This [`BuildContext::setup_build`] calls will fail if builds are disabled.
     /// This method exists to avoid fetching source distributions if we know we can't build them.
     fn build_options(&self) -> &BuildOptions;
 
+    /// Whether to incorporate `tool.uv.sources` when resolving requirements.
+    fn sources(&self) -> SourceStrategy;
+
     /// The index locations being searched.
     fn index_locations(&self) -> &IndexLocations;
 
