@@ -239,6 +239,7 @@ impl Workspace {
         }
     }
 
+    /// Returns `true` if the workspace has a virtual root.
     pub fn is_virtual(&self) -> bool {
         !self
             .packages
@@ -246,6 +247,11 @@ impl Workspace {
             .any(|member| *member.root() == self.install_path)
     }
 
+    /// Returns `true` if the workspace consists solely of a virtual root.
+    pub fn only_virtual(&self) -> bool {
+        self.packages.is_empty()
+    }
+
     /// Returns the set of requirements that include all packages in the workspace.
     pub fn members_requirements(&self) -> impl Iterator<Item = Requirement> + '_ {
         self.packages.values().filter_map(|member| {
