@@ -38,6 +38,7 @@ use uv_resolver::{
 use uv_types::{BuildIsolation, EmptyInstalledPackages, HashStrategy, InFlight};
 use uv_warnings::warn_user;
 
+use crate::commands::pip::loggers::DefaultResolveLogger;
 use crate::commands::pip::{operations, resolution_environment};
 use crate::commands::ExitStatus;
 use crate::printer::Printer;
@@ -76,6 +77,7 @@ pub(crate) async fn pip_compile(
     config_settings: ConfigSettings,
     connectivity: Connectivity,
     no_build_isolation: bool,
+    no_build_isolation_package: Vec<PackageName>,
     build_options: BuildOptions,
     python_version: Option<PythonVersion>,
     python_platform: Option<TargetTriple>,
@@ -303,8 +305,11 @@ pub(crate) async fn pip_compile(
     let build_isolation = if no_build_isolation {
         environment = PythonEnvironment::from_interpreter(interpreter.clone());
         BuildIsolation::Shared(&environment)
-    } else {
+    } else if no_build_isolation_package.is_empty() {
         BuildIsolation::Isolated
+    } else {
+        environment = PythonEnvironment::from_interpreter(interpreter.clone());
+        BuildIsolation::SharedPackage(&environment, &no_build_isolation_package)
     };
 
     let build_dispatch = BuildDispatch::new(
@@ -360,9 +365,9 @@ pub(crate) async fn pip_compile(
         &build_dispatch,
         concurrency,
         options,
+        Box::new(DefaultResolveLogger),
         printer,
         preview,
-        false,
     )
     .await
     {
@@ -402,12 +407,14 @@ pub(crate) async fn pip_compile(
     if include_marker_expression {
         if let ResolverMarkers::SpecificEnvironment(markers) = &markers {
             let relevant_markers = resolution.marker_tree(&top_level_index, markers)?;
-            writeln!(
-                writer,
-                "{}",
-                "# Pinned dependencies known to be valid for:".green()
-            )?;
-            writeln!(writer, "{}", format!("#    {relevant_markers}").green())?;
+            if let Some(relevant_markers) = relevant_markers.contents() {
+                writeln!(
+                    writer,
+                    "{}",
+                    "# Pinned dependencies known to be valid for:".green()
+                )?;
+                writeln!(writer, "{}", format!("#    {relevant_markers}").green())?;
+            }
         }
     }
 
