@@ -20,8 +20,8 @@ use uv_fs::Simplified;
 use uv_installer::{SatisfiesResult, SitePackages};
 use uv_normalize::PackageName;
 use uv_python::{
-    request_from_version_file, EnvironmentPreference, Interpreter, PythonEnvironment, PythonFetch,
-    PythonInstallation, PythonPreference, PythonRequest, VersionRequest,
+    request_from_version_file, EnvironmentPreference, Interpreter, PythonDownloads,
+    PythonEnvironment, PythonInstallation, PythonPreference, PythonRequest, VersionRequest,
 };
 use uv_requirements::{NamedRequirementsResolver, RequirementsSpecification};
 use uv_resolver::{
@@ -31,6 +31,7 @@ use uv_types::{BuildIsolation, EmptyInstalledPackages, HashStrategy};
 use uv_warnings::{warn_user, warn_user_once};
 use uv_workspace::Workspace;
 
+use crate::commands::pip::loggers::{InstallLogger, ResolveLogger};
 use crate::commands::pip::operations::Modifications;
 use crate::commands::reporters::{PythonDownloadReporter, ResolverReporter};
 use crate::commands::{pip, SharedState};
@@ -201,7 +202,7 @@ impl FoundInterpreter {
         workspace: &Workspace,
         python_request: Option<PythonRequest>,
         python_preference: PythonPreference,
-        python_fetch: PythonFetch,
+        python_downloads: PythonDownloads,
         connectivity: Connectivity,
         native_tls: bool,
         cache: &Cache,
@@ -250,11 +251,11 @@ impl FoundInterpreter {
         let reporter = PythonDownloadReporter::single(printer);
 
         // Locate the Python interpreter to use in the environment
-        let python = PythonInstallation::find_or_fetch(
+        let python = PythonInstallation::find_or_download(
             python_request,
             EnvironmentPreference::OnlySystem,
             python_preference,
-            python_fetch,
+            python_downloads,
             &client_builder,
             cache,
             Some(&reporter),
@@ -328,7 +329,7 @@ pub(crate) async fn get_or_init_environment(
     workspace: &Workspace,
     python: Option<PythonRequest>,
     python_preference: PythonPreference,
-    python_fetch: PythonFetch,
+    python_downloads: PythonDownloads,
     connectivity: Connectivity,
     native_tls: bool,
     cache: &Cache,
@@ -338,7 +339,7 @@ pub(crate) async fn get_or_init_environment(
         workspace,
         python,
         python_preference,
-        python_fetch,
+        python_downloads,
         connectivity,
         native_tls,
         cache,
@@ -406,6 +407,7 @@ pub(crate) async fn resolve_names(
         prerelease: _,
         config_setting,
         no_build_isolation,
+        no_build_isolation_package,
         exclude_newer,
         link_mode,
         compile_bytecode: _,
@@ -436,8 +438,11 @@ pub(crate) async fn resolve_names(
     let build_isolation = if *no_build_isolation {
         environment = PythonEnvironment::from_interpreter(interpreter.clone());
         BuildIsolation::Shared(&environment)
-    } else {
+    } else if no_build_isolation_package.is_empty() {
         BuildIsolation::Isolated
+    } else {
+        environment = PythonEnvironment::from_interpreter(interpreter.clone());
+        BuildIsolation::SharedPackage(&environment, no_build_isolation_package)
     };
 
     // TODO(charlie): These are all default values. We should consider whether we want to make them
@@ -488,6 +493,7 @@ pub(crate) async fn resolve_environment<'a>(
     spec: RequirementsSpecification,
     settings: ResolverSettingsRef<'_>,
     state: &SharedState,
+    logger: Box<dyn ResolveLogger>,
     preview: PreviewMode,
     connectivity: Connectivity,
     concurrency: Concurrency,
@@ -505,6 +511,7 @@ pub(crate) async fn resolve_environment<'a>(
         prerelease,
         config_setting,
         no_build_isolation,
+        no_build_isolation_package,
         exclude_newer,
         link_mode,
         upgrade: _,
@@ -548,8 +555,11 @@ pub(crate) async fn resolve_environment<'a>(
     let build_isolation = if no_build_isolation {
         environment = PythonEnvironment::from_interpreter(interpreter.clone());
         BuildIsolation::Shared(&environment)
-    } else {
+    } else if no_build_isolation_package.is_empty() {
         BuildIsolation::Isolated
+    } else {
+        environment = PythonEnvironment::from_interpreter(interpreter.clone());
+        BuildIsolation::SharedPackage(&environment, no_build_isolation_package)
     };
 
     let options = OptionsBuilder::new()
@@ -626,9 +636,9 @@ pub(crate) async fn resolve_environment<'a>(
         &resolve_dispatch,
         concurrency,
         options,
+        logger,
         printer,
         preview,
-        false,
     )
     .await?)
 }
@@ -639,6 +649,7 @@ pub(crate) async fn sync_environment(
     resolution: &Resolution,
     settings: InstallerSettingsRef<'_>,
     state: &SharedState,
+    logger: Box<dyn InstallLogger>,
     preview: PreviewMode,
     connectivity: Connectivity,
     concurrency: Concurrency,
@@ -745,6 +756,7 @@ pub(crate) async fn sync_environment(
         &build_dispatch,
         cache,
         &venv,
+        logger,
         dry_run,
         printer,
         preview,
@@ -763,6 +775,8 @@ pub(crate) async fn update_environment(
     spec: RequirementsSpecification,
     settings: &ResolverInstallerSettings,
     state: &SharedState,
+    resolve: Box<dyn ResolveLogger>,
+    install: Box<dyn InstallLogger>,
     preview: PreviewMode,
     connectivity: Connectivity,
     concurrency: Concurrency,
@@ -780,6 +794,7 @@ pub(crate) async fn update_environment(
         prerelease,
         config_setting,
         no_build_isolation,
+        no_build_isolation_package,
         exclude_newer,
         link_mode,
         compile_bytecode,
@@ -848,8 +863,10 @@ pub(crate) async fn update_environment(
     // Determine whether to enable build isolation.
     let build_isolation = if *no_build_isolation {
         BuildIsolation::Shared(&venv)
-    } else {
+    } else if no_build_isolation_package.is_empty() {
         BuildIsolation::Isolated
+    } else {
+        BuildIsolation::SharedPackage(&venv, no_build_isolation_package)
     };
 
     let options = OptionsBuilder::new()
@@ -922,9 +939,9 @@ pub(crate) async fn update_environment(
         &build_dispatch,
         concurrency,
         options,
+        resolve,
         printer,
         preview,
-        false,
     )
     .await
     {
@@ -950,6 +967,7 @@ pub(crate) async fn update_environment(
         &build_dispatch,
         cache,
         &venv,
+        install,
         dry_run,
         printer,
         preview,
