@@ -18,13 +18,16 @@ use uv_fs::{PythonExt, Simplified, CWD};
 use uv_installer::{SatisfiesResult, SitePackages};
 use uv_normalize::PackageName;
 use uv_python::{
-    request_from_version_file, EnvironmentPreference, Interpreter, PythonEnvironment, PythonFetch,
-    PythonInstallation, PythonPreference, PythonRequest, VersionRequest,
+    request_from_version_file, EnvironmentPreference, Interpreter, PythonDownloads,
+    PythonEnvironment, PythonInstallation, PythonPreference, PythonRequest, VersionRequest,
 };
 use uv_requirements::{RequirementsSource, RequirementsSpecification};
 use uv_warnings::warn_user_once;
 use uv_workspace::{DiscoveryOptions, VirtualProject, Workspace, WorkspaceError};
 
+use crate::commands::pip::loggers::{
+    DefaultInstallLogger, DefaultResolveLogger, SummaryInstallLogger, SummaryResolveLogger,
+};
 use crate::commands::pip::operations::Modifications;
 use crate::commands::project::environment::CachedEnvironment;
 use crate::commands::project::{ProjectError, WorkspacePython};
@@ -50,7 +53,7 @@ pub(crate) async fn run(
     settings: ResolverInstallerSettings,
     preview: PreviewMode,
     python_preference: PythonPreference,
-    python_fetch: PythonFetch,
+    python_downloads: PythonDownloads,
     connectivity: Connectivity,
     concurrency: Concurrency,
     native_tls: bool,
@@ -89,7 +92,8 @@ pub(crate) async fn run(
     // Initialize any shared state.
     let state = SharedState::default();
 
-    let reporter = PythonDownloadReporter::single(printer.filter(show_resolution));
+    // Initialize any output reporters.
+    let download_reporter = PythonDownloadReporter::single(printer);
 
     // Determine whether the command to execute is a PEP 723 script.
     let temp_dir;
@@ -118,14 +122,14 @@ pub(crate) async fn run(
                 .connectivity(connectivity)
                 .native_tls(native_tls);
 
-            let interpreter = PythonInstallation::find_or_fetch(
+            let interpreter = PythonInstallation::find_or_download(
                 python_request,
                 EnvironmentPreference::Any,
                 python_preference,
-                python_fetch,
+                python_downloads,
                 &client_builder,
                 cache,
-                Some(&reporter),
+                Some(&download_reporter),
             )
             .await?
             .into_interpreter();
@@ -139,18 +143,28 @@ pub(crate) async fn run(
                     interpreter,
                     &settings,
                     &state,
+                    if show_resolution {
+                        Box::new(DefaultResolveLogger)
+                    } else {
+                        Box::new(SummaryResolveLogger)
+                    },
+                    if show_resolution {
+                        Box::new(DefaultInstallLogger)
+                    } else {
+                        Box::new(SummaryInstallLogger)
+                    },
                     preview,
                     connectivity,
                     concurrency,
                     native_tls,
                     cache,
-                    printer.filter(show_resolution),
+                    printer,
                 )
                 .await?;
 
                 Some(environment.into_interpreter())
             } else {
-                // Create a virtual environment
+                // Create a virtual environment.
                 temp_dir = cache.environment()?;
                 let environment = uv_virtualenv::create_venv(
                     temp_dir.path(),
@@ -173,11 +187,42 @@ pub(crate) async fn run(
     // Discover and sync the base environment.
     let temp_dir;
     let base_interpreter = if let Some(script_interpreter) = script_interpreter {
-        Some(script_interpreter)
+        // If we found a PEP 723 script and the user provided a project-only setting, warn.
+        if !extras.is_empty() {
+            warn_user_once!("Extras are not supported for Python scripts with inline metadata");
+        }
+        if !dev {
+            warn_user_once!("`--no-dev` is not supported for Python scripts with inline metadata");
+        }
+        if no_project {
+            warn_user_once!(
+                "`--no-project` is a no-op for Python scripts with inline metadata, which always run in isolation"
+            );
+        }
+        if package.is_some() {
+            warn_user_once!(
+                "`--package` is a no-op for Python scripts with inline metadata, which always run in isolation"
+            );
+        }
+        if locked {
+            warn_user_once!(
+                "`--locked` is a no-op for Python scripts with inline metadata, which always run in isolation"
+            );
+        }
+        if frozen {
+            warn_user_once!(
+                "`--frozen` is a no-op for Python scripts with inline metadata, which always run in isolation"
+            );
+        }
+        if isolated {
+            warn_user_once!(
+                "`--isolated` is a no-op for Python scripts with inline metadata, which always run in isolation"
+            );
+        }
+
+        script_interpreter
     } else {
-        let project = if no_project {
-            None
-        } else if let Some(package) = package {
+        let project = if let Some(package) = package {
             // We need a workspace, but we don't need to have a current package, we can be e.g. in
             // the root of a virtual workspace and then switch into the selected package.
             Some(VirtualProject::Project(
@@ -195,6 +240,47 @@ pub(crate) async fn run(
             }
         };
 
+        let project = if no_project {
+            // If the user runs with `--no-project` and we can't find a project, warn.
+            if project.is_none() {
+                warn_user_once!("`--no-project` was provided, but no project was found");
+            }
+
+            // If the user ran with `--no-project` and provided a project-only setting, warn.
+            if !extras.is_empty() {
+                warn_user_once!("Extras have no effect when used alongside `--no-project`");
+            }
+            if !dev {
+                warn_user_once!("`--no-dev` has no effect when used alongside `--no-project`");
+            }
+            if locked {
+                warn_user_once!("`--locked` has no effect when used alongside `--no-project`");
+            }
+            if frozen {
+                warn_user_once!("`--frozen` has no effect when used alongside `--no-project`");
+            }
+
+            None
+        } else {
+            // If we can't find a project and the user provided a project-only setting, warn.
+            if project.is_none() {
+                if !extras.is_empty() {
+                    warn_user_once!("Extras have no effect when used outside of a project");
+                }
+                if !dev {
+                    warn_user_once!("`--no-dev` has no effect when used outside of a project");
+                }
+                if locked {
+                    warn_user_once!("`--locked` has no effect when used outside of a project");
+                }
+                if frozen {
+                    warn_user_once!("`--frozen` has no effect when used outside of a project");
+                }
+            }
+
+            project
+        };
+
         let interpreter = if let Some(project) = project {
             if let Some(project_name) = project.project_name() {
                 debug!(
@@ -226,14 +312,14 @@ pub(crate) async fn run(
                     .await?;
 
                     // Note we force preview on during `uv run` for now since the entire interface is in preview.
-                    PythonInstallation::find_or_fetch(
+                    PythonInstallation::find_or_download(
                         python_request,
                         EnvironmentPreference::Any,
                         python_preference,
-                        python_fetch,
+                        python_downloads,
                         &client_builder,
                         cache,
-                        Some(&reporter),
+                        Some(&download_reporter),
                     )
                     .await?
                     .into_interpreter()
@@ -256,11 +342,11 @@ pub(crate) async fn run(
                     project.workspace(),
                     python.as_deref().map(PythonRequest::parse),
                     python_preference,
-                    python_fetch,
+                    python_downloads,
                     connectivity,
                     native_tls,
                     cache,
-                    printer.filter(show_resolution),
+                    printer,
                 )
                 .await?
             };
@@ -271,12 +357,17 @@ pub(crate) async fn run(
                 project.workspace(),
                 venv.interpreter(),
                 settings.as_ref().into(),
+                if show_resolution {
+                    Box::new(DefaultResolveLogger)
+                } else {
+                    Box::new(SummaryResolveLogger)
+                },
                 preview,
                 connectivity,
                 concurrency,
                 native_tls,
                 cache,
-                printer.filter(show_resolution),
+                printer,
             )
             .await
             {
@@ -300,12 +391,17 @@ pub(crate) async fn run(
                 Modifications::Sufficient,
                 settings.as_ref().into(),
                 &state,
+                if show_resolution {
+                    Box::new(DefaultInstallLogger)
+                } else {
+                    Box::new(SummaryInstallLogger)
+                },
                 preview,
                 connectivity,
                 concurrency,
                 native_tls,
                 cache,
-                printer.filter(show_resolution),
+                printer,
             )
             .await?;
 
@@ -318,15 +414,15 @@ pub(crate) async fn run(
                     .connectivity(connectivity)
                     .native_tls(native_tls);
 
-                let python = PythonInstallation::find_or_fetch(
+                let python = PythonInstallation::find_or_download(
                     python.as_deref().map(PythonRequest::parse),
                     // No opt-in is required for system environments, since we are not mutating it.
                     EnvironmentPreference::Any,
                     python_preference,
-                    python_fetch,
+                    python_downloads,
                     &client_builder,
                     cache,
-                    Some(&reporter),
+                    Some(&download_reporter),
                 )
                 .await?;
 
@@ -352,16 +448,14 @@ pub(crate) async fn run(
             }
         };
 
-        Some(interpreter)
+        interpreter
     };
 
-    if let Some(base_interpreter) = &base_interpreter {
-        debug!(
-            "Using Python {} interpreter at: {}",
-            base_interpreter.python_version(),
-            base_interpreter.sys_executable().display()
-        );
-    }
+    debug!(
+        "Using Python {} interpreter at: {}",
+        base_interpreter.python_version(),
+        base_interpreter.sys_executable().display()
+    );
 
     // Read the requirements.
     let spec = if requirements.is_empty() {
@@ -377,140 +471,77 @@ pub(crate) async fn run(
         Some(spec)
     };
 
-    // Determine whether the base environment satisfies the ephemeral requirements. If we don't have
-    // any `--with` requirements, and we already have a base environment, then there's no need to
-    // create an additional environment.
-    let skip_ephemeral = base_interpreter.as_ref().is_some_and(|base_interpreter| {
-        // No additional requirements.
-        let Some(spec) = spec.as_ref() else {
-            return true;
-        };
-
-        let Ok(site_packages) = SitePackages::from_interpreter(base_interpreter) else {
-            return false;
-        };
-
-        if !(settings.reinstall.is_none() && settings.reinstall.is_none()) {
-            return false;
-        }
-
-        match site_packages.satisfies(&spec.requirements, &spec.constraints) {
-            // If the requirements are already satisfied, we're done.
-            Ok(SatisfiesResult::Fresh {
-                recursive_requirements,
-            }) => {
-                debug!(
-                    "Base environment satisfies requirements: {}",
-                    recursive_requirements
-                        .iter()
-                        .map(|entry| entry.requirement.to_string())
-                        .sorted()
-                        .join(" | ")
-                );
-                true
-            }
-            Ok(SatisfiesResult::Unsatisfied(requirement)) => {
-                debug!("At least one requirement is not satisfied in the base environment: {requirement}");
-                false
-            }
-            Err(err) => {
-                debug!("Failed to check requirements against base environment: {err}");
-                false
-            }
-        }
-    });
-
     // If necessary, create an environment for the ephemeral requirements or command.
     let temp_dir;
-    let ephemeral_env = if skip_ephemeral {
+    let ephemeral_env = if can_skip_ephemeral(spec.as_ref(), &base_interpreter, &settings) {
         None
     } else {
         debug!("Creating ephemeral environment");
 
-        // Discover an interpreter.
-        let interpreter = if let Some(base_interpreter) = &base_interpreter {
-            base_interpreter.clone()
-        } else {
-            let client_builder = BaseClientBuilder::new()
-                .connectivity(connectivity)
-                .native_tls(native_tls);
-
-            // Note we force preview on during `uv run` for now since the entire interface is in preview
-            PythonInstallation::find_or_fetch(
-                python.as_deref().map(PythonRequest::parse),
-                EnvironmentPreference::Any,
-                python_preference,
-                python_fetch,
-                &client_builder,
-                cache,
-                Some(&reporter),
-            )
-            .await?
-            .into_interpreter()
-        };
-
-        // TODO(charlie): Pass the already-installed versions as preferences, or even as the
-        // "installed" packages, so that we can skip re-installing them in the ephemeral
-        // environment.
-
-        // Create a virtual environment
-        temp_dir = cache.environment()?;
-        let venv = uv_virtualenv::create_venv(
-            temp_dir.path(),
-            interpreter,
-            uv_virtualenv::Prompt::None,
-            false,
-            false,
-            false,
-        )?;
-
-        match spec {
-            None => Some(venv),
-            Some(spec) if spec.is_empty() => Some(venv),
+        Some(match spec.filter(|spec| !spec.is_empty()) {
+            None => {
+                // Create a virtual environment
+                temp_dir = cache.environment()?;
+                uv_virtualenv::create_venv(
+                    temp_dir.path(),
+                    base_interpreter.clone(),
+                    uv_virtualenv::Prompt::None,
+                    false,
+                    false,
+                    false,
+                )?
+            }
             Some(spec) => {
                 debug!("Syncing ephemeral requirements");
-                // Install the ephemeral requirements.
-                Some(
-                    project::update_environment(
-                        venv,
-                        spec,
-                        &settings,
-                        &state,
-                        preview,
-                        connectivity,
-                        concurrency,
-                        native_tls,
-                        cache,
-                        printer.filter(show_resolution),
-                    )
-                    .await?,
+
+                CachedEnvironment::get_or_create(
+                    spec,
+                    base_interpreter.clone(),
+                    &settings,
+                    &state,
+                    if show_resolution {
+                        Box::new(DefaultResolveLogger)
+                    } else {
+                        Box::new(SummaryResolveLogger)
+                    },
+                    if show_resolution {
+                        Box::new(DefaultInstallLogger)
+                    } else {
+                        Box::new(SummaryInstallLogger)
+                    },
+                    preview,
+                    connectivity,
+                    concurrency,
+                    native_tls,
+                    cache,
+                    printer,
                 )
+                .await?
+                .into()
             }
-        }
+        })
     };
 
     // If we're running in an ephemeral environment, add a `sitecustomize.py` to enable loading of
     // the base environment's site packages. Setting `PYTHONPATH` is insufficient, as it doesn't
     // resolve `.pth` files in the base environment.
     if let Some(ephemeral_env) = ephemeral_env.as_ref() {
-        if let Some(base_interpreter) = base_interpreter.as_ref() {
-            let ephemeral_site_packages = ephemeral_env
-                .site_packages()
-                .next()
-                .ok_or_else(|| anyhow!("Ephemeral environment has no site packages directory"))?;
-            let base_site_packages = base_interpreter
-                .site_packages()
-                .next()
-                .ok_or_else(|| anyhow!("Base environment has no site packages directory"))?;
+        let ephemeral_site_packages = ephemeral_env
+            .site_packages()
+            .next()
+            .ok_or_else(|| anyhow!("Ephemeral environment has no site packages directory"))?;
+        let base_site_packages = base_interpreter
+            .site_packages()
+            .next()
+            .ok_or_else(|| anyhow!("Base environment has no site packages directory"))?;
 
-            fs_err::write(
-                ephemeral_site_packages.join("sitecustomize.py"),
-                format!(
-                    "import site; site.addsitedir(\"{}\")",
-                    base_site_packages.escape_for_python()
-                ),
-            )?;
-        }
+        fs_err::write(
+            ephemeral_site_packages.join("sitecustomize.py"),
+            format!(
+                "import site; site.addsitedir(\"{}\")",
+                base_site_packages.escape_for_python()
+            ),
+        )?;
     }
 
     debug!("Running `{command}`");
@@ -522,12 +553,7 @@ pub(crate) async fn run(
             .as_ref()
             .map(PythonEnvironment::scripts)
             .into_iter()
-            .chain(
-                base_interpreter
-                    .as_ref()
-                    .map(Interpreter::scripts)
-                    .into_iter(),
-            )
+            .chain(std::iter::once(base_interpreter.scripts()))
             .map(PathBuf::from)
             .chain(
                 std::env::var_os("PATH")
@@ -564,6 +590,53 @@ pub(crate) async fn run(
     }
 }
 
+/// Returns `true` if we can skip creating an additional ephemeral environment in `uv run`.
+fn can_skip_ephemeral(
+    spec: Option<&RequirementsSpecification>,
+    base_interpreter: &Interpreter,
+    settings: &ResolverInstallerSettings,
+) -> bool {
+    // No additional requirements.
+    let Some(spec) = spec.as_ref() else {
+        return true;
+    };
+
+    let Ok(site_packages) = SitePackages::from_interpreter(base_interpreter) else {
+        return false;
+    };
+
+    if !(settings.reinstall.is_none() && settings.reinstall.is_none()) {
+        return false;
+    }
+
+    match site_packages.satisfies(&spec.requirements, &spec.constraints) {
+        // If the requirements are already satisfied, we're done.
+        Ok(SatisfiesResult::Fresh {
+            recursive_requirements,
+        }) => {
+            debug!(
+                "Base environment satisfies requirements: {}",
+                recursive_requirements
+                    .iter()
+                    .map(|entry| entry.requirement.to_string())
+                    .sorted()
+                    .join(" | ")
+            );
+            true
+        }
+        Ok(SatisfiesResult::Unsatisfied(requirement)) => {
+            debug!(
+                "At least one requirement is not satisfied in the base environment: {requirement}"
+            );
+            false
+        }
+        Err(err) => {
+            debug!("Failed to check requirements against base environment: {err}");
+            false
+        }
+    }
+}
+
 #[derive(Debug)]
 enum RunCommand {
     /// Execute a `python` script.
