@@ -10,12 +10,13 @@ use uv_dispatch::BuildDispatch;
 use uv_fs::CWD;
 use uv_installer::SitePackages;
 use uv_normalize::{PackageName, DEV_DEPENDENCIES};
-use uv_python::{PythonEnvironment, PythonFetch, PythonPreference, PythonRequest};
+use uv_python::{PythonDownloads, PythonEnvironment, PythonPreference, PythonRequest};
 use uv_resolver::{FlatIndex, Lock};
 use uv_types::{BuildIsolation, HashStrategy};
 use uv_warnings::warn_user_once;
 use uv_workspace::{DiscoveryOptions, VirtualProject, Workspace};
 
+use crate::commands::pip::loggers::{DefaultInstallLogger, DefaultResolveLogger, InstallLogger};
 use crate::commands::pip::operations::Modifications;
 use crate::commands::project::lock::do_safe_lock;
 use crate::commands::project::{ProjectError, SharedState};
@@ -34,7 +35,7 @@ pub(crate) async fn sync(
     modifications: Modifications,
     python: Option<String>,
     python_preference: PythonPreference,
-    python_fetch: PythonFetch,
+    python_downloads: PythonDownloads,
     settings: ResolverInstallerSettings,
     preview: PreviewMode,
     connectivity: Connectivity,
@@ -64,7 +65,7 @@ pub(crate) async fn sync(
         project.workspace(),
         python.as_deref().map(PythonRequest::parse),
         python_preference,
-        python_fetch,
+        python_downloads,
         connectivity,
         native_tls,
         cache,
@@ -78,6 +79,7 @@ pub(crate) async fn sync(
         project.workspace(),
         venv.interpreter(),
         settings.as_ref().into(),
+        Box::new(DefaultResolveLogger),
         preview,
         connectivity,
         concurrency,
@@ -111,6 +113,7 @@ pub(crate) async fn sync(
         modifications,
         settings.as_ref().into(),
         &state,
+        Box::new(DefaultInstallLogger),
         preview,
         connectivity,
         concurrency,
@@ -133,6 +136,7 @@ pub(super) async fn do_sync(
     modifications: Modifications,
     settings: InstallerSettingsRef<'_>,
     state: &SharedState,
+    logger: Box<dyn InstallLogger>,
     preview: PreviewMode,
     connectivity: Connectivity,
     concurrency: Concurrency,
@@ -260,6 +264,7 @@ pub(super) async fn do_sync(
         &build_dispatch,
         cache,
         venv,
+        logger,
         dry_run,
         printer,
         preview,
