@@ -15,7 +15,8 @@ use uv_fs::CWD;
 use uv_python::downloads::{DownloadResult, ManagedPythonDownload, PythonDownloadRequest};
 use uv_python::managed::{ManagedPythonInstallation, ManagedPythonInstallations};
 use uv_python::{
-    requests_from_version_file, PythonRequest, PYTHON_VERSIONS_FILENAME, PYTHON_VERSION_FILENAME,
+    requests_from_version_file, PythonDownloads, PythonRequest, PYTHON_VERSIONS_FILENAME,
+    PYTHON_VERSION_FILENAME,
 };
 use uv_warnings::warn_user_once;
 
@@ -28,6 +29,7 @@ use crate::printer::Printer;
 pub(crate) async fn install(
     targets: Vec<String>,
     reinstall: bool,
+    python_downloads: PythonDownloads,
     native_tls: bool,
     connectivity: Connectivity,
     preview: PreviewMode,
@@ -124,6 +126,14 @@ pub(crate) async fn install(
         return Ok(ExitStatus::Success);
     }
 
+    if matches!(python_downloads, PythonDownloads::Never) {
+        writeln!(
+            printer.stderr(),
+            "Python downloads are not allowed (`python-downloads = \"never\"`). Change to `python-downloads = \"manual\"` to allow explicit installs.",
+        )?;
+        return Ok(ExitStatus::Failure);
+    }
+
     let downloads = unfilled_requests
         .into_iter()
         // Populate the download requests with defaults
@@ -235,9 +245,9 @@ pub(crate) async fn install(
         for (key, err) in errors {
             writeln!(
                 printer.stderr(),
-                "Failed to install {}: {}",
+                "{}: Failed to install {}: {err}",
+                "error".red().bold(),
                 key.green(),
-                err
             )?;
         }
         return Ok(ExitStatus::Failure);
