@@ -1,37 +1,31 @@
-use std::collections::BTreeSet;
-use std::ffi::OsString;
 use std::fmt::Write;
 use std::str::FromStr;
 
-use anyhow::{bail, Context, Result};
-use itertools::Itertools;
+use anyhow::{bail, Result};
+use distribution_types::UnresolvedRequirementSpecification;
 use owo_colors::OwoColorize;
-use tracing::{debug, warn};
+use tracing::debug;
 
-use distribution_types::{Name, UnresolvedRequirementSpecification};
-use pypi_types::Requirement;
 use uv_cache::Cache;
 use uv_client::{BaseClientBuilder, Connectivity};
 use uv_configuration::{Concurrency, PreviewMode};
-#[cfg(unix)]
-use uv_fs::replace_symlink;
-use uv_fs::Simplified;
-use uv_installer::SitePackages;
 use uv_normalize::PackageName;
 use uv_python::{
-    EnvironmentPreference, PythonFetch, PythonInstallation, PythonPreference, PythonRequest,
+    EnvironmentPreference, PythonDownloads, PythonInstallation, PythonPreference, PythonRequest,
 };
 use uv_requirements::{RequirementsSource, RequirementsSpecification};
-use uv_shell::Shell;
-use uv_tool::{entrypoint_paths, find_executable_directory, InstalledTools, Tool, ToolEntrypoint};
+use uv_settings::{ResolverInstallerOptions, ToolOptions};
+use uv_tool::InstalledTools;
 use uv_warnings::{warn_user, warn_user_once};
 
-use crate::commands::reporters::PythonDownloadReporter;
+use crate::commands::pip::loggers::{DefaultInstallLogger, DefaultResolveLogger};
 
+use crate::commands::tool::common::remove_entrypoints;
 use crate::commands::{
     project::{resolve_environment, resolve_names, sync_environment, update_environment},
-    tool::common::matching_packages,
+    tool::common::InstallAction,
 };
+use crate::commands::{reporters::PythonDownloadReporter, tool::common::install_executables};
 use crate::commands::{ExitStatus, SharedState};
 use crate::printer::Printer;
 use crate::settings::ResolverInstallerSettings;
@@ -44,10 +38,11 @@ pub(crate) async fn install(
     with: &[RequirementsSource],
     python: Option<String>,
     force: bool,
+    options: ResolverInstallerOptions,
     settings: ResolverInstallerSettings,
     preview: PreviewMode,
     python_preference: PythonPreference,
-    python_fetch: PythonFetch,
+    python_downloads: PythonDownloads,
     connectivity: Connectivity,
     concurrency: Concurrency,
     native_tls: bool,
@@ -68,11 +63,11 @@ pub(crate) async fn install(
 
     // Pre-emptively identify a Python interpreter. We need an interpreter to resolve any unnamed
     // requirements, even if we end up using a different interpreter for the tool install itself.
-    let interpreter = PythonInstallation::find_or_fetch(
+    let interpreter = PythonInstallation::find_or_download(
         python_request.clone(),
         EnvironmentPreference::OnlySystem,
         python_preference,
-        python_fetch,
+        python_downloads,
         &client_builder,
         cache,
         Some(&reporter),
@@ -82,6 +77,7 @@ pub(crate) async fn install(
 
     // Initialize any shared state.
     let state = SharedState::default();
+
     let client_builder = BaseClientBuilder::new()
         .connectivity(connectivity)
         .native_tls(native_tls);
@@ -184,6 +180,9 @@ pub(crate) async fn install(
         requirements
     };
 
+    // Convert to tool options.
+    let options = ToolOptions::from(options);
+
     let installed_tools = InstalledTools::from_settings()?.init()?;
     let _lock = installed_tools.acquire_lock()?;
 
@@ -243,12 +242,21 @@ pub(crate) async fn install(
             if requirements == receipt {
                 // And the user didn't request a reinstall or upgrade...
                 if !force && settings.reinstall.is_none() && settings.upgrade.is_none() {
-                    // We're done.
+                    if *tool_receipt.options() != options {
+                        // ...but the options differ, we need to update the receipt.
+                        installed_tools.add_tool_receipt(
+                            &from.name,
+                            tool_receipt.clone().with_options(options),
+                        )?;
+                    }
+
+                    // We're done, though we might need to update the receipt.
                     writeln!(
                         printer.stderr(),
                         "`{from}` is already installed",
                         from = from.cyan()
                     )?;
+
                     return Ok(ExitStatus::Success);
                 }
             }
@@ -275,6 +283,8 @@ pub(crate) async fn install(
             spec,
             &settings,
             &state,
+            Box::new(DefaultResolveLogger),
+            Box::new(DefaultInstallLogger),
             preview,
             connectivity,
             concurrency,
@@ -299,6 +309,7 @@ pub(crate) async fn install(
             spec,
             settings.as_ref().into(),
             &state,
+            Box::new(DefaultResolveLogger),
             preview,
             connectivity,
             concurrency,
@@ -322,6 +333,7 @@ pub(crate) async fn install(
             &resolution.into(),
             settings.as_ref().into(),
             &state,
+            Box::new(DefaultInstallLogger),
             preview,
             connectivity,
             concurrency,
@@ -332,213 +344,15 @@ pub(crate) async fn install(
         .await?
     };
 
-    let site_packages = SitePackages::from_environment(&environment)?;
-    let installed = site_packages.get_packages(&from.name);
-    let Some(installed_dist) = installed.first().copied() else {
-        bail!("Expected at least one requirement")
-    };
-
-    // Find a suitable path to install into
-    let executable_directory = find_executable_directory()?;
-    fs_err::create_dir_all(&executable_directory)
-        .context("Failed to create executable directory")?;
-
-    debug!(
-        "Installing tool executables into: {}",
-        executable_directory.user_display()
-    );
-
-    let entry_points = entrypoint_paths(
-        &site_packages,
-        installed_dist.name(),
-        installed_dist.version(),
-    )?;
-
-    // Determine the entry points targets
-    // Use a sorted collection for deterministic output
-    let target_entry_points = entry_points
-        .into_iter()
-        .map(|(name, source_path)| {
-            let target_path = executable_directory.join(
-                source_path
-                    .file_name()
-                    .map(std::borrow::ToOwned::to_owned)
-                    .unwrap_or_else(|| OsString::from(name.clone())),
-            );
-            (name, source_path, target_path)
-        })
-        .collect::<BTreeSet<_>>();
-
-    if target_entry_points.is_empty() {
-        writeln!(
-            printer.stdout(),
-            "No executables are provided by `{from}`",
-            from = from.name.cyan()
-        )?;
-
-        hint_executable_from_dependency(&from, &site_packages, printer)?;
-
-        // Clean up the environment we just created.
-        installed_tools.remove_environment(&from.name)?;
-
-        return Ok(ExitStatus::Failure);
-    }
-
-    // Check if they exist, before installing
-    let mut existing_entry_points = target_entry_points
-        .iter()
-        .filter(|(_, _, target_path)| target_path.exists())
-        .peekable();
-
-    // Ignore any existing entrypoints if the user passed `--force`, or the existing recept was
-    // broken.
-    if force || invalid_tool_receipt {
-        for (name, _, target) in existing_entry_points {
-            debug!("Removing existing executable: `{name}`");
-            fs_err::remove_file(target)?;
-        }
-    } else if existing_entry_points.peek().is_some() {
-        // Clean up the environment we just created
-        installed_tools.remove_environment(&from.name)?;
-
-        let existing_entry_points = existing_entry_points
-            // SAFETY: We know the target has a filename because we just constructed it above
-            .map(|(_, _, target)| target.file_name().unwrap().to_string_lossy())
-            .collect::<Vec<_>>();
-        let (s, exists) = if existing_entry_points.len() == 1 {
-            ("", "exists")
-        } else {
-            ("s", "exist")
-        };
-        bail!(
-            "Executable{s} already {exists}: {} (use `--force` to overwrite)",
-            existing_entry_points
-                .iter()
-                .map(|name| name.bold())
-                .join(", ")
-        )
-    }
-
-    for (name, source_path, target_path) in &target_entry_points {
-        debug!("Installing executable: `{name}`");
-        #[cfg(unix)]
-        replace_symlink(source_path, target_path).context("Failed to install executable")?;
-        #[cfg(windows)]
-        fs_err::copy(source_path, target_path).context("Failed to install entrypoint")?;
-    }
-
-    let s = if target_entry_points.len() == 1 {
-        ""
-    } else {
-        "s"
-    };
-    writeln!(
-        printer.stderr(),
-        "Installed {} executable{s}: {}",
-        target_entry_points.len(),
-        target_entry_points
-            .iter()
-            .map(|(name, _, _)| name.bold())
-            .join(", ")
-    )?;
-
-    debug!("Adding receipt for tool `{}`", from.name);
-    let tool = Tool::new(
-        requirements.into_iter().collect(),
+    install_executables(
+        &environment,
+        &from.name,
+        &installed_tools,
+        options,
+        force || invalid_tool_receipt,
         python,
-        target_entry_points
-            .into_iter()
-            .map(|(name, _, target_path)| ToolEntrypoint::new(name, target_path)),
-    );
-    installed_tools.add_tool_receipt(&from.name, tool)?;
-
-    // If the executable directory isn't on the user's PATH, warn.
-    if !Shell::contains_path(&executable_directory) {
-        if let Some(shell) = Shell::from_env() {
-            if let Some(command) = shell.prepend_path(&executable_directory) {
-                if shell.configuration_files().is_empty() {
-                    warn_user!(
-                        "`{}` is not on your PATH. To use installed tools, run `{}`.",
-                        executable_directory.simplified_display().cyan(),
-                        command.green()
-                    );
-                } else {
-                    warn_user!(
-                        "`{}` is not on your PATH. To use installed tools, run `{}` or `{}`.",
-                        executable_directory.simplified_display().cyan(),
-                        command.green(),
-                        "uv tool update-shell".green()
-                    );
-                }
-            } else {
-                warn_user!(
-                    "`{}` is not on your PATH. To use installed tools, add the directory to your PATH.",
-                    executable_directory.simplified_display().cyan(),
-                );
-            }
-        } else {
-            warn_user!(
-                "`{}` is not on your PATH. To use installed tools, add the directory to your PATH.",
-                executable_directory.simplified_display().cyan(),
-            );
-        }
-    }
-
-    Ok(ExitStatus::Success)
-}
-
-/// Remove any entrypoints attached to the [`Tool`].
-fn remove_entrypoints(tool: &Tool) {
-    for executable in tool
-        .entrypoints()
-        .iter()
-        .map(|entrypoint| &entrypoint.install_path)
-    {
-        debug!("Removing executable: `{}`", executable.simplified_display());
-        if let Err(err) = fs_err::remove_file(executable) {
-            warn!(
-                "Failed to remove executable: `{}`: {err}",
-                executable.simplified_display()
-            );
-        }
-    }
-}
-
-/// Displays a hint if an executable matching the package name can be found in a dependency of the package.
-fn hint_executable_from_dependency(
-    from: &Requirement,
-    site_packages: &SitePackages,
-    printer: Printer,
-) -> Result<()> {
-    let packages = matching_packages(from.name.as_ref(), site_packages);
-    match packages.as_slice() {
-        [] => {}
-        [package] => {
-            let command = format!("uv tool install {}", package.name());
-            writeln!(
-                    printer.stdout(),
-                    "However, an executable with the name `{}` is available via dependency `{}`.\nDid you mean `{}`?",
-                    from.name.cyan(),
-                    package.name().cyan(),
-                    command.bold(),
-                )?;
-        }
-        packages => {
-            writeln!(
-                    printer.stdout(),
-                    "However, an executable with the name `{}` is available via the following dependencies::",
-                    from.name.cyan(),
-                )?;
-
-            for package in packages {
-                writeln!(printer.stdout(), "- {}", package.name().cyan())?;
-            }
-            writeln!(
-                printer.stdout(),
-                "Did you mean to install one of them instead?"
-            )?;
-        }
-    }
-
-    Ok(())
+        requirements,
+        InstallAction::Install,
+        printer,
+    )
 }
