@@ -5,26 +5,28 @@ use owo_colors::OwoColorize;
 
 use uv_cache::Cache;
 use uv_configuration::PreviewMode;
+use uv_fs::Simplified;
 use uv_tool::InstalledTools;
-use uv_warnings::warn_user_once;
+use uv_warnings::{warn_user, warn_user_once};
 
 use crate::commands::ExitStatus;
 use crate::printer::Printer;
 
 /// List installed tools.
 pub(crate) async fn list(
+    show_paths: bool,
     preview: PreviewMode,
     cache: &Cache,
     printer: Printer,
 ) -> Result<ExitStatus> {
     if preview.is_disabled() {
-        warn_user_once!("`uv tool list` is experimental and may change without warning.");
+        warn_user_once!("`uv tool list` is experimental and may change without warning");
     }
 
     let installed_tools = InstalledTools::from_settings()?;
     let _lock = match installed_tools.acquire_lock() {
         Ok(lock) => lock,
-        Err(uv_tool::Error::IO(err)) if err.kind() == std::io::ErrorKind::NotFound => {
+        Err(uv_tool::Error::Io(err)) if err.kind() == std::io::ErrorKind::NotFound => {
             writeln!(printer.stderr(), "No tools installed")?;
             return Ok(ExitStatus::Success);
         }
@@ -40,6 +42,15 @@ pub(crate) async fn list(
     }
 
     for (name, tool) in tools {
+        // Skip invalid tools
+        let Ok(tool) = tool else {
+            warn_user!(
+                "Ignoring malformed tool `{name}` (run `{}` to remove)",
+                format!("uv tool uninstall {name}").green()
+            );
+            continue;
+        };
+
         // Output tool name and version
         let version = match installed_tools.version(&name, cache) {
             Ok(version) => version,
@@ -49,11 +60,29 @@ pub(crate) async fn list(
             }
         };
 
-        writeln!(printer.stdout(), "{}", format!("{name} v{version}").bold())?;
+        if show_paths {
+            writeln!(
+                printer.stdout(),
+                "{} ({})",
+                format!("{name} v{version}").bold(),
+                installed_tools.tool_dir(&name).simplified_display().cyan()
+            )?;
+        } else {
+            writeln!(printer.stdout(), "{}", format!("{name} v{version}").bold())?;
+        }
 
         // Output tool entrypoints
         for entrypoint in tool.entrypoints() {
-            writeln!(printer.stdout(), "- {}", &entrypoint.name)?;
+            if show_paths {
+                writeln!(
+                    printer.stdout(),
+                    "- {} ({})",
+                    entrypoint.name,
+                    entrypoint.install_path.simplified_display().cyan()
+                )?;
+            } else {
+                writeln!(printer.stdout(), "- {}", entrypoint.name)?;
+            }
         }
     }
 
