@@ -9,7 +9,10 @@ use install_wheel_rs::linker::LinkMode;
 use pep508_rs::{ExtraName, RequirementOrigin};
 use pypi_types::Requirement;
 use uv_cache::{CacheArgs, Refresh};
-use uv_cli::options::{flag, resolver_installer_options, resolver_options};
+use uv_cli::{
+    options::{flag, resolver_installer_options, resolver_options},
+    ToolUpgradeArgs,
+};
 use uv_cli::{
     AddArgs, ColorChoice, Commands, ExternalCommand, GlobalArgs, InitArgs, ListFormat, LockArgs,
     Maybe, PipCheckArgs, PipCompileArgs, PipFreezeArgs, PipInstallArgs, PipListArgs, PipShowArgs,
@@ -24,12 +27,13 @@ use uv_configuration::{
     SourceStrategy, TargetTriple, Upgrade,
 };
 use uv_normalize::PackageName;
-use uv_python::{Prefix, PythonFetch, PythonPreference, PythonVersion, Target};
+use uv_python::{Prefix, PythonDownloads, PythonPreference, PythonVersion, Target};
 use uv_requirements::RequirementsSource;
 use uv_resolver::{AnnotationStyle, DependencyMode, ExcludeNewer, PrereleaseMode, ResolutionMode};
 use uv_settings::{
     Combine, FilesystemOptions, Options, PipOptions, ResolverInstallerOptions, ResolverOptions,
 };
+use uv_warnings::warn_user_once;
 use uv_workspace::pyproject::DependencyType;
 
 use crate::commands::pip::operations::Modifications;
@@ -46,7 +50,7 @@ pub(crate) struct GlobalSettings {
     pub(crate) show_settings: bool,
     pub(crate) preview: PreviewMode,
     pub(crate) python_preference: PythonPreference,
-    pub(crate) python_fetch: PythonFetch,
+    pub(crate) python_downloads: PythonDownloads,
     pub(crate) no_progress: bool,
 }
 
@@ -113,9 +117,9 @@ impl GlobalSettings {
                 .python_preference
                 .combine(workspace.and_then(|workspace| workspace.globals.python_preference))
                 .unwrap_or(default_python_preference),
-            python_fetch: args
-                .python_fetch
-                .combine(workspace.and_then(|workspace| workspace.globals.python_fetch))
+            python_downloads: flag(args.allow_python_downloads, args.no_python_downloads)
+                .map(PythonDownloads::from)
+                .combine(workspace.and_then(|workspace| workspace.globals.python_downloads))
                 .unwrap_or_default(),
             no_progress: args.no_progress,
         }
@@ -316,6 +320,7 @@ pub(crate) struct ToolInstallSettings {
     pub(crate) with_requirements: Vec<PathBuf>,
     pub(crate) python: Option<String>,
     pub(crate) refresh: Refresh,
+    pub(crate) options: ResolverInstallerOptions,
     pub(crate) settings: ResolverInstallerSettings,
     pub(crate) force: bool,
     pub(crate) editable: bool,
@@ -338,6 +343,15 @@ impl ToolInstallSettings {
             python,
         } = args;
 
+        let options = resolver_installer_options(installer, build).combine(
+            filesystem
+                .map(FilesystemOptions::into_options)
+                .map(|options| options.top_level)
+                .unwrap_or_default(),
+        );
+
+        let settings = ResolverInstallerSettings::from(options.clone());
+
         Self {
             package,
             from,
@@ -350,10 +364,50 @@ impl ToolInstallSettings {
             force,
             editable,
             refresh: Refresh::from(refresh),
-            settings: ResolverInstallerSettings::combine(
-                resolver_installer_options(installer, build),
-                filesystem,
-            ),
+            options,
+            settings,
+        }
+    }
+}
+
+/// The resolved settings to use for a `tool upgrade` invocation.
+#[allow(clippy::struct_excessive_bools)]
+#[derive(Debug, Clone)]
+pub(crate) struct ToolUpgradeSettings {
+    pub(crate) name: Option<PackageName>,
+    pub(crate) args: ResolverInstallerOptions,
+    pub(crate) filesystem: ResolverInstallerOptions,
+}
+
+impl ToolUpgradeSettings {
+    /// Resolve the [`ToolUpgradeSettings`] from the CLI and filesystem configuration.
+    #[allow(clippy::needless_pass_by_value)]
+    pub(crate) fn resolve(args: ToolUpgradeArgs, filesystem: Option<FilesystemOptions>) -> Self {
+        let ToolUpgradeArgs {
+            name,
+            all,
+            mut installer,
+            build,
+        } = args;
+
+        if installer.upgrade {
+            // If `--upgrade` was passed explicitly, warn.
+            warn_user_once!("`--upgrade` is enabled by default on `uv tool upgrade`");
+        } else if installer.upgrade_package.is_empty() {
+            // If neither `--upgrade` nor `--upgrade-package` were passed in, assume `--upgrade`.
+            installer.upgrade = true;
+        }
+
+        let args = resolver_installer_options(installer, build);
+        let filesystem = filesystem
+            .map(FilesystemOptions::into_options)
+            .map(|options| options.top_level)
+            .unwrap_or_default();
+
+        Self {
+            name: name.filter(|_| !all),
+            args,
+            filesystem,
         }
     }
 }
@@ -722,7 +776,7 @@ pub(crate) struct RemoveSettings {
     pub(crate) locked: bool,
     pub(crate) frozen: bool,
     pub(crate) no_sync: bool,
-    pub(crate) requirements: Vec<PackageName>,
+    pub(crate) packages: Vec<PackageName>,
     pub(crate) dependency_type: DependencyType,
     pub(crate) package: Option<PackageName>,
     pub(crate) python: Option<String>,
@@ -737,7 +791,7 @@ impl RemoveSettings {
         let RemoveArgs {
             dev,
             optional,
-            requirements,
+            packages,
             no_sync,
             locked,
             frozen,
@@ -760,7 +814,7 @@ impl RemoveSettings {
             locked,
             frozen,
             no_sync,
-            requirements,
+            packages,
             dependency_type,
             package,
             python,
@@ -1531,6 +1585,7 @@ pub(crate) struct ResolverSettings {
     pub(crate) prerelease: PrereleaseMode,
     pub(crate) config_setting: ConfigSettings,
     pub(crate) no_build_isolation: bool,
+    pub(crate) no_build_isolation_package: Vec<PackageName>,
     pub(crate) exclude_newer: Option<ExcludeNewer>,
     pub(crate) link_mode: LinkMode,
     pub(crate) upgrade: Upgrade,
@@ -1547,6 +1602,7 @@ pub(crate) struct ResolverSettingsRef<'a> {
     pub(crate) prerelease: PrereleaseMode,
     pub(crate) config_setting: &'a ConfigSettings,
     pub(crate) no_build_isolation: bool,
+    pub(crate) no_build_isolation_package: &'a [PackageName],
     pub(crate) exclude_newer: Option<ExcludeNewer>,
     pub(crate) link_mode: LinkMode,
     pub(crate) upgrade: &'a Upgrade,
@@ -1557,90 +1613,14 @@ pub(crate) struct ResolverSettingsRef<'a> {
 impl ResolverSettings {
     /// Resolve the [`ResolverSettings`] from the CLI and filesystem configuration.
     pub(crate) fn combine(args: ResolverOptions, filesystem: Option<FilesystemOptions>) -> Self {
-        let ResolverInstallerOptions {
-            index_url,
-            extra_index_url,
-            no_index,
-            find_links,
-            index_strategy,
-            keyring_provider,
-            resolution,
-            prerelease,
-            config_settings,
-            no_build_isolation,
-            exclude_newer,
-            link_mode,
-            compile_bytecode: _,
-            no_sources,
-            upgrade,
-            upgrade_package,
-            reinstall: _,
-            reinstall_package: _,
-            no_build,
-            no_build_package,
-            no_binary,
-            no_binary_package,
-        } = filesystem
-            .map(FilesystemOptions::into_options)
-            .map(|options| options.top_level)
-            .unwrap_or_default();
+        let options = args.combine(ResolverOptions::from(
+            filesystem
+                .map(FilesystemOptions::into_options)
+                .map(|options| options.top_level)
+                .unwrap_or_default(),
+        ));
 
-        Self {
-            index_locations: IndexLocations::new(
-                args.index_url.combine(index_url),
-                args.extra_index_url
-                    .combine(extra_index_url)
-                    .unwrap_or_default(),
-                args.find_links.combine(find_links).unwrap_or_default(),
-                args.no_index.combine(no_index).unwrap_or_default(),
-            ),
-            resolution: args.resolution.combine(resolution).unwrap_or_default(),
-            prerelease: args.prerelease.combine(prerelease).unwrap_or_default(),
-            index_strategy: args
-                .index_strategy
-                .combine(index_strategy)
-                .unwrap_or_default(),
-            keyring_provider: args
-                .keyring_provider
-                .combine(keyring_provider)
-                .unwrap_or_default(),
-            config_setting: args
-                .config_settings
-                .combine(config_settings)
-                .unwrap_or_default(),
-            no_build_isolation: args
-                .no_build_isolation
-                .combine(no_build_isolation)
-                .unwrap_or_default(),
-            exclude_newer: args.exclude_newer.combine(exclude_newer),
-            link_mode: args.link_mode.combine(link_mode).unwrap_or_default(),
-            upgrade: Upgrade::from_args(
-                args.upgrade.combine(upgrade),
-                args.upgrade_package
-                    .combine(upgrade_package)
-                    .into_iter()
-                    .flatten()
-                    .map(Requirement::from)
-                    .collect(),
-            ),
-            build_options: BuildOptions::new(
-                NoBinary::from_args(
-                    args.no_binary.combine(no_binary),
-                    args.no_binary_package
-                        .combine(no_binary_package)
-                        .unwrap_or_default(),
-                ),
-                NoBuild::from_args(
-                    args.no_build.combine(no_build),
-                    args.no_build_package
-                        .combine(no_build_package)
-                        .unwrap_or_default(),
-                ),
-            ),
-            sources: SourceStrategy::from_args(
-                args.no_sources.combine(no_sources).unwrap_or_default(),
-            ),
-        }
+        Self::from(options)
     }
 
     pub(crate) fn as_ref(&self) -> ResolverSettingsRef {
@@ -1652,6 +1632,7 @@ impl ResolverSettings {
             prerelease: self.prerelease,
             config_setting: &self.config_setting,
             no_build_isolation: self.no_build_isolation,
+            no_build_isolation_package: &self.no_build_isolation_package,
             exclude_newer: self.exclude_newer,
             link_mode: self.link_mode,
             upgrade: &self.upgrade,
@@ -1661,28 +1642,40 @@ impl ResolverSettings {
     }
 }
 
-/// The resolved settings to use for an invocation of the uv CLI with both resolver and installer
-/// capabilities.
-///
-/// Represents the shared settings that are used across all uv commands outside the `pip` API.
-/// Analogous to the settings contained in the `[tool.uv]` table, combined with [`ResolverInstallerArgs`].
-#[allow(clippy::struct_excessive_bools)]
-#[derive(Debug, Clone, Default)]
-pub(crate) struct ResolverInstallerSettings {
-    pub(crate) index_locations: IndexLocations,
-    pub(crate) index_strategy: IndexStrategy,
-    pub(crate) keyring_provider: KeyringProviderType,
-    pub(crate) resolution: ResolutionMode,
-    pub(crate) prerelease: PrereleaseMode,
-    pub(crate) config_setting: ConfigSettings,
-    pub(crate) no_build_isolation: bool,
-    pub(crate) exclude_newer: Option<ExcludeNewer>,
-    pub(crate) link_mode: LinkMode,
-    pub(crate) compile_bytecode: bool,
-    pub(crate) sources: SourceStrategy,
-    pub(crate) upgrade: Upgrade,
-    pub(crate) reinstall: Reinstall,
-    pub(crate) build_options: BuildOptions,
+impl From<ResolverOptions> for ResolverSettings {
+    fn from(value: ResolverOptions) -> Self {
+        Self {
+            index_locations: IndexLocations::new(
+                value.index_url,
+                value.extra_index_url.unwrap_or_default(),
+                value.find_links.unwrap_or_default(),
+                value.no_index.unwrap_or_default(),
+            ),
+            resolution: value.resolution.unwrap_or_default(),
+            prerelease: value.prerelease.unwrap_or_default(),
+            index_strategy: value.index_strategy.unwrap_or_default(),
+            keyring_provider: value.keyring_provider.unwrap_or_default(),
+            config_setting: value.config_settings.unwrap_or_default(),
+            no_build_isolation: value.no_build_isolation.unwrap_or_default(),
+            no_build_isolation_package: value.no_build_isolation_package.unwrap_or_default(),
+            exclude_newer: value.exclude_newer,
+            link_mode: value.link_mode.unwrap_or_default(),
+            sources: SourceStrategy::from_args(value.no_sources.unwrap_or_default()),
+            upgrade: Upgrade::from_args(
+                value.upgrade,
+                value
+                    .upgrade_package
+                    .into_iter()
+                    .flatten()
+                    .map(Requirement::from)
+                    .collect(),
+            ),
+            build_options: BuildOptions::new(
+                NoBinary::from_args(value.no_binary, value.no_binary_package.unwrap_or_default()),
+                NoBuild::from_args(value.no_build, value.no_build_package.unwrap_or_default()),
+            ),
+        }
+    }
 }
 
 #[derive(Debug, Clone)]
@@ -1694,6 +1687,7 @@ pub(crate) struct ResolverInstallerSettingsRef<'a> {
     pub(crate) prerelease: PrereleaseMode,
     pub(crate) config_setting: &'a ConfigSettings,
     pub(crate) no_build_isolation: bool,
+    pub(crate) no_build_isolation_package: &'a [PackageName],
     pub(crate) exclude_newer: Option<ExcludeNewer>,
     pub(crate) link_mode: LinkMode,
     pub(crate) compile_bytecode: bool,
@@ -1703,106 +1697,46 @@ pub(crate) struct ResolverInstallerSettingsRef<'a> {
     pub(crate) build_options: &'a BuildOptions,
 }
 
+/// The resolved settings to use for an invocation of the uv CLI with both resolver and installer
+/// capabilities.
+///
+/// Represents the shared settings that are used across all uv commands outside the `pip` API.
+/// Analogous to the settings contained in the `[tool.uv]` table, combined with [`ResolverInstallerArgs`].
+#[allow(clippy::struct_excessive_bools)]
+#[derive(Debug, Clone, Default, serde::Serialize, serde::Deserialize)]
+#[serde(rename_all = "kebab-case", deny_unknown_fields)]
+pub(crate) struct ResolverInstallerSettings {
+    pub(crate) index_locations: IndexLocations,
+    pub(crate) index_strategy: IndexStrategy,
+    pub(crate) keyring_provider: KeyringProviderType,
+    pub(crate) resolution: ResolutionMode,
+    pub(crate) prerelease: PrereleaseMode,
+    pub(crate) config_setting: ConfigSettings,
+    pub(crate) no_build_isolation: bool,
+    pub(crate) no_build_isolation_package: Vec<PackageName>,
+    pub(crate) exclude_newer: Option<ExcludeNewer>,
+    pub(crate) link_mode: LinkMode,
+    pub(crate) compile_bytecode: bool,
+    pub(crate) sources: SourceStrategy,
+    pub(crate) upgrade: Upgrade,
+    pub(crate) reinstall: Reinstall,
+    pub(crate) build_options: BuildOptions,
+}
+
 impl ResolverInstallerSettings {
-    /// Resolve the [`ResolverInstallerSettings`] from the CLI and filesystem configuration.
+    /// Reconcile the [`ResolverInstallerSettings`] from the CLI and filesystem configuration.
     pub(crate) fn combine(
         args: ResolverInstallerOptions,
         filesystem: Option<FilesystemOptions>,
     ) -> Self {
-        let ResolverInstallerOptions {
-            index_url,
-            extra_index_url,
-            no_index,
-            find_links,
-            index_strategy,
-            keyring_provider,
-            resolution,
-            prerelease,
-            config_settings,
-            no_build_isolation,
-            exclude_newer,
-            link_mode,
-            compile_bytecode,
-            no_sources,
-            upgrade,
-            upgrade_package,
-            reinstall,
-            reinstall_package,
-            no_build,
-            no_build_package,
-            no_binary,
-            no_binary_package,
-        } = filesystem
-            .map(FilesystemOptions::into_options)
-            .map(|options| options.top_level)
-            .unwrap_or_default();
+        let options = args.combine(
+            filesystem
+                .map(FilesystemOptions::into_options)
+                .map(|options| options.top_level)
+                .unwrap_or_default(),
+        );
 
-        Self {
-            index_locations: IndexLocations::new(
-                args.index_url.combine(index_url),
-                args.extra_index_url
-                    .combine(extra_index_url)
-                    .unwrap_or_default(),
-                args.find_links.combine(find_links).unwrap_or_default(),
-                args.no_index.combine(no_index).unwrap_or_default(),
-            ),
-            resolution: args.resolution.combine(resolution).unwrap_or_default(),
-            prerelease: args.prerelease.combine(prerelease).unwrap_or_default(),
-            index_strategy: args
-                .index_strategy
-                .combine(index_strategy)
-                .unwrap_or_default(),
-            keyring_provider: args
-                .keyring_provider
-                .combine(keyring_provider)
-                .unwrap_or_default(),
-            config_setting: args
-                .config_settings
-                .combine(config_settings)
-                .unwrap_or_default(),
-            no_build_isolation: args
-                .no_build_isolation
-                .combine(no_build_isolation)
-                .unwrap_or_default(),
-            exclude_newer: args.exclude_newer.combine(exclude_newer),
-            link_mode: args.link_mode.combine(link_mode).unwrap_or_default(),
-            sources: SourceStrategy::from_args(
-                args.no_sources.combine(no_sources).unwrap_or_default(),
-            ),
-            compile_bytecode: args
-                .compile_bytecode
-                .combine(compile_bytecode)
-                .unwrap_or_default(),
-            upgrade: Upgrade::from_args(
-                args.upgrade.combine(upgrade),
-                args.upgrade_package
-                    .combine(upgrade_package)
-                    .into_iter()
-                    .flatten()
-                    .map(Requirement::from)
-                    .collect(),
-            ),
-            reinstall: Reinstall::from_args(
-                args.reinstall.combine(reinstall),
-                args.reinstall_package
-                    .combine(reinstall_package)
-                    .unwrap_or_default(),
-            ),
-            build_options: BuildOptions::new(
-                NoBinary::from_args(
-                    args.no_binary.combine(no_binary),
-                    args.no_binary_package
-                        .combine(no_binary_package)
-                        .unwrap_or_default(),
-                ),
-                NoBuild::from_args(
-                    args.no_build.combine(no_build),
-                    args.no_build_package
-                        .combine(no_build_package)
-                        .unwrap_or_default(),
-                ),
-            ),
-        }
+        Self::from(options)
     }
 
     pub(crate) fn as_ref(&self) -> ResolverInstallerSettingsRef {
@@ -1814,6 +1748,7 @@ impl ResolverInstallerSettings {
             prerelease: self.prerelease,
             config_setting: &self.config_setting,
             no_build_isolation: self.no_build_isolation,
+            no_build_isolation_package: &self.no_build_isolation_package,
             exclude_newer: self.exclude_newer,
             link_mode: self.link_mode,
             compile_bytecode: self.compile_bytecode,
@@ -1825,6 +1760,47 @@ impl ResolverInstallerSettings {
     }
 }
 
+impl From<ResolverInstallerOptions> for ResolverInstallerSettings {
+    fn from(value: ResolverInstallerOptions) -> Self {
+        Self {
+            index_locations: IndexLocations::new(
+                value.index_url,
+                value.extra_index_url.unwrap_or_default(),
+                value.find_links.unwrap_or_default(),
+                value.no_index.unwrap_or_default(),
+            ),
+            resolution: value.resolution.unwrap_or_default(),
+            prerelease: value.prerelease.unwrap_or_default(),
+            index_strategy: value.index_strategy.unwrap_or_default(),
+            keyring_provider: value.keyring_provider.unwrap_or_default(),
+            config_setting: value.config_settings.unwrap_or_default(),
+            no_build_isolation: value.no_build_isolation.unwrap_or_default(),
+            no_build_isolation_package: value.no_build_isolation_package.unwrap_or_default(),
+            exclude_newer: value.exclude_newer,
+            link_mode: value.link_mode.unwrap_or_default(),
+            sources: SourceStrategy::from_args(value.no_sources.unwrap_or_default()),
+            compile_bytecode: value.compile_bytecode.unwrap_or_default(),
+            upgrade: Upgrade::from_args(
+                value.upgrade,
+                value
+                    .upgrade_package
+                    .into_iter()
+                    .flatten()
+                    .map(Requirement::from)
+                    .collect(),
+            ),
+            reinstall: Reinstall::from_args(
+                value.reinstall,
+                value.reinstall_package.unwrap_or_default(),
+            ),
+            build_options: BuildOptions::new(
+                NoBinary::from_args(value.no_binary, value.no_binary_package.unwrap_or_default()),
+                NoBuild::from_args(value.no_build, value.no_build_package.unwrap_or_default()),
+            ),
+        }
+    }
+}
+
 /// The resolved settings to use for an invocation of the `pip` CLI.
 ///
 /// Represents the shared settings that are used across all `pip` commands. Analogous to the
@@ -1842,6 +1818,7 @@ pub(crate) struct PipSettings {
     pub(crate) index_strategy: IndexStrategy,
     pub(crate) keyring_provider: KeyringProviderType,
     pub(crate) no_build_isolation: bool,
+    pub(crate) no_build_isolation_package: Vec<PackageName>,
     pub(crate) build_options: BuildOptions,
     pub(crate) allow_empty_requirements: bool,
     pub(crate) strict: bool,
@@ -1900,6 +1877,7 @@ impl PipSettings {
             no_binary,
             only_binary,
             no_build_isolation,
+            no_build_isolation_package,
             strict,
             extra,
             all_extras,
@@ -1952,6 +1930,7 @@ impl PipSettings {
             prerelease: top_level_prerelease,
             config_settings: top_level_config_settings,
             no_build_isolation: top_level_no_build_isolation,
+            no_build_isolation_package: top_level_no_build_isolation_package,
             exclude_newer: top_level_exclude_newer,
             link_mode: top_level_link_mode,
             compile_bytecode: top_level_compile_bytecode,
@@ -1980,6 +1959,8 @@ impl PipSettings {
         let prerelease = prerelease.combine(top_level_prerelease);
         let config_settings = config_settings.combine(top_level_config_settings);
         let no_build_isolation = no_build_isolation.combine(top_level_no_build_isolation);
+        let no_build_isolation_package =
+            no_build_isolation_package.combine(top_level_no_build_isolation_package);
         let exclude_newer = exclude_newer.combine(top_level_exclude_newer);
         let link_mode = link_mode.combine(top_level_link_mode);
         let compile_bytecode = compile_bytecode.combine(top_level_compile_bytecode);
@@ -2054,6 +2035,10 @@ impl PipSettings {
                 .no_build_isolation
                 .combine(no_build_isolation)
                 .unwrap_or_default(),
+            no_build_isolation_package: args
+                .no_build_isolation_package
+                .combine(no_build_isolation_package)
+                .unwrap_or_default(),
             config_setting: args
                 .config_settings
                 .combine(config_settings)
@@ -2172,6 +2157,7 @@ impl<'a> From<ResolverInstallerSettingsRef<'a>> for ResolverSettingsRef<'a> {
             prerelease: settings.prerelease,
             config_setting: settings.config_setting,
             no_build_isolation: settings.no_build_isolation,
+            no_build_isolation_package: settings.no_build_isolation_package,
             exclude_newer: settings.exclude_newer,
             link_mode: settings.link_mode,
             upgrade: settings.upgrade,
