@@ -216,7 +216,7 @@ fn root_package_splits_transitive_too() -> Result<()> {
     [options]
     exclude-newer = "2024-03-25 00:00:00 UTC"
 
-    [[distribution]]
+    [[package]]
     name = "a"
     version = "0.1.0"
     source = { editable = "." }
@@ -226,7 +226,7 @@ fn root_package_splits_transitive_too() -> Result<()> {
         { name = "b" },
     ]
 
-    [[distribution]]
+    [[package]]
     name = "anyio"
     version = "4.2.0"
     source = { registry = "https://pypi.org/simple" }
@@ -242,7 +242,7 @@ fn root_package_splits_transitive_too() -> Result<()> {
         { url = "https://files.pythonhosted.org/packages/bf/cd/d6d9bb1dadf73e7af02d18225cbd2c93f8552e13130484f1c8dcfece292b/anyio-4.2.0-py3-none-any.whl", hash = "sha256:745843b39e829e108e518c489b31dc757de7d2131d53fac32bd8df268227bfee", size = 85481 },
     ]
 
-    [[distribution]]
+    [[package]]
     name = "anyio"
     version = "4.3.0"
     source = { registry = "https://pypi.org/simple" }
@@ -258,7 +258,7 @@ fn root_package_splits_transitive_too() -> Result<()> {
         { url = "https://files.pythonhosted.org/packages/14/fd/2f20c40b45e4fb4324834aea24bd4afdf1143390242c0b33774da0e2e34f/anyio-4.3.0-py3-none-any.whl", hash = "sha256:048e05d0f6caeed70d731f3db756d35dcc1f35747c8c403364a8332c630441b8", size = 85584 },
     ]
 
-    [[distribution]]
+    [[package]]
     name = "b"
     version = "0.1.0"
     source = { directory = "b" }
@@ -267,7 +267,7 @@ fn root_package_splits_transitive_too() -> Result<()> {
         { name = "b2", marker = "python_version >= '3.12'" },
     ]
 
-    [[distribution]]
+    [[package]]
     name = "b1"
     version = "0.1.0"
     source = { directory = "../b1" }
@@ -275,7 +275,7 @@ fn root_package_splits_transitive_too() -> Result<()> {
         { name = "iniconfig", version = "1.1.1", source = { url = "https://files.pythonhosted.org/packages/9b/dd/b3c12c6d707058fa947864b67f0c4e0c39ef8610988d7baea9578f3c48f3/iniconfig-1.1.1-py2.py3-none-any.whl" }, marker = "python_version < '3.12'" },
     ]
 
-    [[distribution]]
+    [[package]]
     name = "b2"
     version = "0.1.0"
     source = { directory = "../b2" }
@@ -283,7 +283,7 @@ fn root_package_splits_transitive_too() -> Result<()> {
         { name = "iniconfig", version = "2.0.0", source = { url = "https://files.pythonhosted.org/packages/ef/a6/62565a6e1cf69e10f5727360368e451d4b7f58beeac6173dc9db836a5b46/iniconfig-2.0.0-py3-none-any.whl" }, marker = "python_version >= '3.12'" },
     ]
 
-    [[distribution]]
+    [[package]]
     name = "idna"
     version = "3.6"
     source = { registry = "https://pypi.org/simple" }
@@ -292,7 +292,7 @@ fn root_package_splits_transitive_too() -> Result<()> {
         { url = "https://files.pythonhosted.org/packages/c2/e7/a82b05cf63a603df6e68d59ae6a68bf5064484a0718ea5033660af4b54a9/idna-3.6-py3-none-any.whl", hash = "sha256:c05567e9c24a6b9faaa835c4821bad0590fbb9d5779e7caa6e1cc4978e7eb24f", size = 61567 },
     ]
 
-    [[distribution]]
+    [[package]]
     name = "iniconfig"
     version = "1.1.1"
     source = { url = "https://files.pythonhosted.org/packages/9b/dd/b3c12c6d707058fa947864b67f0c4e0c39ef8610988d7baea9578f3c48f3/iniconfig-1.1.1-py2.py3-none-any.whl" }
@@ -303,7 +303,7 @@ fn root_package_splits_transitive_too() -> Result<()> {
         { url = "https://files.pythonhosted.org/packages/9b/dd/b3c12c6d707058fa947864b67f0c4e0c39ef8610988d7baea9578f3c48f3/iniconfig-1.1.1-py2.py3-none-any.whl", hash = "sha256:011e24c64b7f47f6ebd835bb12a743f2fbe9a26d4cecaa7f53bc4f35ee9da8b3" },
     ]
 
-    [[distribution]]
+    [[package]]
     name = "iniconfig"
     version = "2.0.0"
     source = { url = "https://files.pythonhosted.org/packages/ef/a6/62565a6e1cf69e10f5727360368e451d4b7f58beeac6173dc9db836a5b46/iniconfig-2.0.0-py3-none-any.whl" }
@@ -314,7 +314,7 @@ fn root_package_splits_transitive_too() -> Result<()> {
         { url = "https://files.pythonhosted.org/packages/ef/a6/62565a6e1cf69e10f5727360368e451d4b7f58beeac6173dc9db836a5b46/iniconfig-2.0.0-py3-none-any.whl", hash = "sha256:b6a85871a79d2e3b22d2d1b94ac2824226a63c6b741c88f7ae975f18b6778374" },
     ]
 
-    [[distribution]]
+    [[package]]
     name = "sniffio"
     version = "1.3.1"
     source = { registry = "https://pypi.org/simple" }
@@ -392,7 +392,7 @@ fn root_package_splits_other_dependencies_too() -> Result<()> {
     [options]
     exclude-newer = "2024-03-25 00:00:00 UTC"
 
-    [[distribution]]
+    [[package]]
     name = "a"
     version = "0.1.0"
     source = { editable = "." }
@@ -403,7 +403,7 @@ fn root_package_splits_other_dependencies_too() -> Result<()> {
         { name = "b2", marker = "python_version >= '3.12'" },
     ]
 
-    [[distribution]]
+    [[package]]
     name = "anyio"
     version = "4.2.0"
     source = { registry = "https://pypi.org/simple" }
@@ -419,7 +419,7 @@ fn root_package_splits_other_dependencies_too() -> Result<()> {
         { url = "https://files.pythonhosted.org/packages/bf/cd/d6d9bb1dadf73e7af02d18225cbd2c93f8552e13130484f1c8dcfece292b/anyio-4.2.0-py3-none-any.whl", hash = "sha256:745843b39e829e108e518c489b31dc757de7d2131d53fac32bd8df268227bfee", size = 85481 },
     ]
 
-    [[distribution]]
+    [[package]]
     name = "anyio"
     version = "4.3.0"
     source = { registry = "https://pypi.org/simple" }
@@ -435,7 +435,7 @@ fn root_package_splits_other_dependencies_too() -> Result<()> {
         { url = "https://files.pythonhosted.org/packages/14/fd/2f20c40b45e4fb4324834aea24bd4afdf1143390242c0b33774da0e2e34f/anyio-4.3.0-py3-none-any.whl", hash = "sha256:048e05d0f6caeed70d731f3db756d35dcc1f35747c8c403364a8332c630441b8", size = 85584 },
     ]
 
-    [[distribution]]
+    [[package]]
     name = "b1"
     version = "0.1.0"
     source = { directory = "b1" }
@@ -443,7 +443,7 @@ fn root_package_splits_other_dependencies_too() -> Result<()> {
         { name = "iniconfig", version = "1.1.1", source = { registry = "https://pypi.org/simple" }, marker = "python_version < '3.12'" },
     ]
 
-    [[distribution]]
+    [[package]]
     name = "b2"
     version = "0.1.0"
     source = { directory = "b2" }
@@ -451,7 +451,7 @@ fn root_package_splits_other_dependencies_too() -> Result<()> {
         { name = "iniconfig", version = "2.0.0", source = { registry = "https://pypi.org/simple" }, marker = "python_version >= '3.12'" },
     ]
 
-    [[distribution]]
+    [[package]]
     name = "idna"
     version = "3.6"
     source = { registry = "https://pypi.org/simple" }
@@ -460,7 +460,7 @@ fn root_package_splits_other_dependencies_too() -> Result<()> {
         { url = "https://files.pythonhosted.org/packages/c2/e7/a82b05cf63a603df6e68d59ae6a68bf5064484a0718ea5033660af4b54a9/idna-3.6-py3-none-any.whl", hash = "sha256:c05567e9c24a6b9faaa835c4821bad0590fbb9d5779e7caa6e1cc4978e7eb24f", size = 61567 },
     ]
 
-    [[distribution]]
+    [[package]]
     name = "iniconfig"
     version = "1.1.1"
     source = { registry = "https://pypi.org/simple" }
@@ -472,7 +472,7 @@ fn root_package_splits_other_dependencies_too() -> Result<()> {
         { url = "https://files.pythonhosted.org/packages/9b/dd/b3c12c6d707058fa947864b67f0c4e0c39ef8610988d7baea9578f3c48f3/iniconfig-1.1.1-py2.py3-none-any.whl", hash = "sha256:011e24c64b7f47f6ebd835bb12a743f2fbe9a26d4cecaa7f53bc4f35ee9da8b3", size = 4990 },
     ]
 
-    [[distribution]]
+    [[package]]
     name = "iniconfig"
     version = "2.0.0"
     source = { registry = "https://pypi.org/simple" }
@@ -484,7 +484,7 @@ fn root_package_splits_other_dependencies_too() -> Result<()> {
         { url = "https://files.pythonhosted.org/packages/ef/a6/62565a6e1cf69e10f5727360368e451d4b7f58beeac6173dc9db836a5b46/iniconfig-2.0.0-py3-none-any.whl", hash = "sha256:b6a85871a79d2e3b22d2d1b94ac2824226a63c6b741c88f7ae975f18b6778374", size = 5892 },
     ]
 
-    [[distribution]]
+    [[package]]
     name = "sniffio"
     version = "1.3.1"
     source = { registry = "https://pypi.org/simple" }
@@ -539,7 +539,7 @@ fn branching_between_registry_and_direct_url() -> Result<()> {
     [options]
     exclude-newer = "2024-03-25 00:00:00 UTC"
 
-    [[distribution]]
+    [[package]]
     name = "a"
     version = "0.1.0"
     source = { editable = "." }
@@ -548,7 +548,7 @@ fn branching_between_registry_and_direct_url() -> Result<()> {
         { name = "iniconfig", version = "2.0.0", source = { url = "https://files.pythonhosted.org/packages/ef/a6/62565a6e1cf69e10f5727360368e451d4b7f58beeac6173dc9db836a5b46/iniconfig-2.0.0-py3-none-any.whl" }, marker = "python_version >= '3.12'" },
     ]
 
-    [[distribution]]
+    [[package]]
     name = "iniconfig"
     version = "1.1.1"
     source = { registry = "https://pypi.org/simple" }
@@ -560,7 +560,7 @@ fn branching_between_registry_and_direct_url() -> Result<()> {
         { url = "https://files.pythonhosted.org/packages/9b/dd/b3c12c6d707058fa947864b67f0c4e0c39ef8610988d7baea9578f3c48f3/iniconfig-1.1.1-py2.py3-none-any.whl", hash = "sha256:011e24c64b7f47f6ebd835bb12a743f2fbe9a26d4cecaa7f53bc4f35ee9da8b3", size = 4990 },
     ]
 
-    [[distribution]]
+    [[package]]
     name = "iniconfig"
     version = "2.0.0"
     source = { url = "https://files.pythonhosted.org/packages/ef/a6/62565a6e1cf69e10f5727360368e451d4b7f58beeac6173dc9db836a5b46/iniconfig-2.0.0-py3-none-any.whl" }
@@ -618,7 +618,7 @@ fn branching_urls_of_different_sources_disjoint() -> Result<()> {
     [options]
     exclude-newer = "2024-03-25 00:00:00 UTC"
 
-    [[distribution]]
+    [[package]]
     name = "a"
     version = "0.1.0"
     source = { editable = "." }
@@ -627,7 +627,7 @@ fn branching_urls_of_different_sources_disjoint() -> Result<()> {
         { name = "iniconfig", version = "2.0.0", source = { git = "https://github.com/pytest-dev/iniconfig?rev=93f5930e668c0d1ddf4597e38dd0dea4e2665e7a#93f5930e668c0d1ddf4597e38dd0dea4e2665e7a" }, marker = "python_version >= '3.12'" },
     ]
 
-    [[distribution]]
+    [[package]]
     name = "iniconfig"
     version = "1.1.1"
     source = { url = "https://files.pythonhosted.org/packages/9b/dd/b3c12c6d707058fa947864b67f0c4e0c39ef8610988d7baea9578f3c48f3/iniconfig-1.1.1-py2.py3-none-any.whl" }
@@ -638,7 +638,7 @@ fn branching_urls_of_different_sources_disjoint() -> Result<()> {
         { url = "https://files.pythonhosted.org/packages/9b/dd/b3c12c6d707058fa947864b67f0c4e0c39ef8610988d7baea9578f3c48f3/iniconfig-1.1.1-py2.py3-none-any.whl", hash = "sha256:011e24c64b7f47f6ebd835bb12a743f2fbe9a26d4cecaa7f53bc4f35ee9da8b3" },
     ]
 
-    [[distribution]]
+    [[package]]
     name = "iniconfig"
     version = "2.0.0"
     source = { git = "https://github.com/pytest-dev/iniconfig?rev=93f5930e668c0d1ddf4597e38dd0dea4e2665e7a#93f5930e668c0d1ddf4597e38dd0dea4e2665e7a" }
@@ -735,7 +735,7 @@ fn dont_pre_visit_url_packages() -> Result<()> {
     [options]
     exclude-newer = "2024-03-25 00:00:00 UTC"
 
-    [[distribution]]
+    [[package]]
     name = "a"
     version = "0.1.0"
     source = { editable = "." }
@@ -744,7 +744,7 @@ fn dont_pre_visit_url_packages() -> Result<()> {
         { name = "c" },
     ]
 
-    [[distribution]]
+    [[package]]
     name = "b"
     version = "0.1.0"
     source = { directory = "b" }
@@ -752,7 +752,7 @@ fn dont_pre_visit_url_packages() -> Result<()> {
         { name = "c" },
     ]
 
-    [[distribution]]
+    [[package]]
     name = "c"
     version = "0.1.0"
     source = { directory = "../c" }
