@@ -3,6 +3,7 @@
 use anyhow::Result;
 use assert_cmd::prelude::*;
 use assert_fs::prelude::*;
+use insta::assert_snapshot;
 
 use common::{uv_snapshot, TestContext};
 
@@ -183,7 +184,6 @@ fn empty() -> Result<()> {
 
     ----- stderr -----
     warning: `uv sync` is experimental and may change without warning
-    warning: No `requires-python` value found in the workspace. Defaulting to `>=3.12`.
     Resolved 0 packages in [TIME]
     Audited 0 packages in [TIME]
     "###);
@@ -198,7 +198,6 @@ fn empty() -> Result<()> {
 
     ----- stderr -----
     warning: `uv sync` is experimental and may change without warning
-    warning: No `requires-python` value found in the workspace. Defaulting to `>=3.12`.
     Resolved 0 packages in [TIME]
     Audited 0 packages in [TIME]
     "###);
@@ -583,3 +582,205 @@ fn sync_reset_state() -> Result<()> {
 
     Ok(())
 }
+
+#[test]
+fn sync_build_isolation_package() -> Result<()> {
+    let context = TestContext::new("3.12");
+
+    let pyproject_toml = context.temp_dir.child("pyproject.toml");
+    pyproject_toml.write_str(
+        r#"
+        [project]
+        name = "project"
+        version = "0.1.0"
+        requires-python = ">=3.12"
+        dependencies = [
+            "iniconfig @ https://files.pythonhosted.org/packages/d7/4b/cbd8e699e64a6f16ca3a8220661b5f83792b3017d0f79807cb8708d33913/iniconfig-2.0.0.tar.gz",
+        ]
+        [build-system]
+        requires = [
+          "setuptools >= 40.9.0",
+        ]
+        build-backend = "setuptools.build_meta"
+        "#,
+    )?;
+
+    // Running `uv sync` should fail for iniconfig.
+    let filters = std::iter::once((r"exit code: 1", "exit status: 1"))
+        .chain(context.filters())
+        .collect::<Vec<_>>();
+    uv_snapshot!(filters, context.sync().arg("--no-build-isolation-package").arg("iniconfig"), @r###"
+    success: false
+    exit_code: 2
+    ----- stdout -----
+
+    ----- stderr -----
+    warning: `uv sync` is experimental and may change without warning
+    error: Failed to download and build: `iniconfig @ https://files.pythonhosted.org/packages/d7/4b/cbd8e699e64a6f16ca3a8220661b5f83792b3017d0f79807cb8708d33913/iniconfig-2.0.0.tar.gz`
+      Caused by: Failed to build: `iniconfig @ https://files.pythonhosted.org/packages/d7/4b/cbd8e699e64a6f16ca3a8220661b5f83792b3017d0f79807cb8708d33913/iniconfig-2.0.0.tar.gz`
+      Caused by: Build backend failed to determine metadata through `prepare_metadata_for_build_wheel` with exit status: 1
+    --- stdout:
+
+    --- stderr:
+    Traceback (most recent call last):
+      File "<string>", line 8, in <module>
+    ModuleNotFoundError: No module named 'hatchling'
+    ---
+    "###);
+
+    // Install `hatchinling`, `hatch-vs` for iniconfig
+    uv_snapshot!(context.filters(), context.pip_install().arg("hatchling").arg("hatch-vcs"), @r###"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Resolved 9 packages in [TIME]
+    Prepared 9 packages in [TIME]
+    Installed 9 packages in [TIME]
+     + hatch-vcs==0.4.0
+     + hatchling==1.22.4
+     + packaging==24.0
+     + pathspec==0.12.1
+     + pluggy==1.4.0
+     + setuptools==69.2.0
+     + setuptools-scm==8.0.4
+     + trove-classifiers==2024.3.3
+     + typing-extensions==4.10.0
+    "###);
+
+    // Running `uv sync` should succeed.
+    uv_snapshot!(context.filters(), context.sync().arg("--no-build-isolation-package").arg("iniconfig"), @r###"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    warning: `uv sync` is experimental and may change without warning
+    Resolved 2 packages in [TIME]
+    Prepared 2 packages in [TIME]
+    Uninstalled 9 packages in [TIME]
+    Installed 2 packages in [TIME]
+     - hatch-vcs==0.4.0
+     - hatchling==1.22.4
+     + iniconfig==2.0.0 (from https://files.pythonhosted.org/packages/d7/4b/cbd8e699e64a6f16ca3a8220661b5f83792b3017d0f79807cb8708d33913/iniconfig-2.0.0.tar.gz)
+     - packaging==24.0
+     - pathspec==0.12.1
+     - pluggy==1.4.0
+     + project==0.1.0 (from file://[TEMP_DIR]/)
+     - setuptools==69.2.0
+     - setuptools-scm==8.0.4
+     - trove-classifiers==2024.3.3
+     - typing-extensions==4.10.0
+    "###);
+
+    assert!(context.temp_dir.child("uv.lock").exists());
+
+    Ok(())
+}
+
+/// Test that relative wheel paths are correctly preserved.
+#[test]
+fn sync_relative_wheel() -> Result<()> {
+    // TODO(charlie): On Windows, this test currently prepares two packages (vs. one of Unix). This
+    // is due to an error in path canonicalization, and GitHub Actions on Windows have a symlink
+    // in the path.
+    //
+    // See: https://github.com/astral-sh/uv/issues/5979
+    let context = TestContext::new("3.12").with_filtered_counts();
+
+    let requirements = r#"[project]
+    name = "relative_wheel"
+    version = "0.1.0"
+    requires-python = ">=3.12"
+    dependencies = ["ok"]
+
+    [tool.uv.sources]
+    ok = { path = "wheels/ok-1.0.0-py3-none-any.whl" }
+
+    [build-system]
+    requires = ["hatchling"]
+    build-backend = "hatchling.build"
+    "#;
+
+    context
+        .temp_dir
+        .child("src/relative_wheel/__init__.py")
+        .touch()?;
+
+    context
+        .temp_dir
+        .child("pyproject.toml")
+        .write_str(requirements)?;
+
+    context.temp_dir.child("wheels").create_dir_all()?;
+    fs_err::copy(
+        "../../scripts/links/ok-1.0.0-py3-none-any.whl",
+        context.temp_dir.join("wheels/ok-1.0.0-py3-none-any.whl"),
+    )?;
+
+    uv_snapshot!(context.filters(), context.sync(), @r###"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    warning: `uv sync` is experimental and may change without warning
+    warning: `uv.sources` is experimental and may change without warning
+    Resolved [N] packages in [TIME]
+    Prepared [N] packages in [TIME]
+    Installed [N] packages in [TIME]
+     + ok==1.0.0 (from file://[TEMP_DIR]/wheels/ok-1.0.0-py3-none-any.whl)
+     + relative-wheel==0.1.0 (from file://[TEMP_DIR]/)
+    "###);
+
+    let lock = fs_err::read_to_string(context.temp_dir.join("uv.lock"))?;
+
+    insta::with_settings!(
+        {
+            filters => context.filters(),
+        },
+        {
+            assert_snapshot!(
+                lock, @r###"
+            version = 1
+            requires-python = ">=3.12"
+
+            [options]
+            exclude-newer = "2024-03-25 00:00:00 UTC"
+
+            [[package]]
+            name = "ok"
+            version = "1.0.0"
+            source = { path = "wheels/ok-1.0.0-py3-none-any.whl" }
+            wheels = [
+                { filename = "ok-1.0.0-py3-none-any.whl", hash = "sha256:79f0b33e6ce1e09eaa1784c8eee275dfe84d215d9c65c652f07c18e85fdaac5f" },
+            ]
+
+            [[package]]
+            name = "relative-wheel"
+            version = "0.1.0"
+            source = { editable = "." }
+            dependencies = [
+                { name = "ok" },
+            ]
+            "###
+            );
+        }
+    );
+
+    // Check that we can re-read the lockfile.
+    uv_snapshot!(context.filters(), context.sync(), @r###"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    warning: `uv sync` is experimental and may change without warning
+    warning: `uv.sources` is experimental and may change without warning
+    Resolved [N] packages in [TIME]
+    Audited [N] packages in [TIME]
+    "###);
+
+    Ok(())
+}
