@@ -838,6 +838,25 @@ fn tool_run_without_output() {
     let tool_dir = context.temp_dir.child("tools");
     let bin_dir = context.temp_dir.child("bin");
 
+    // On the first run, only show the summary line.
+    uv_snapshot!(context.filters(), context.tool_run()
+        .env_remove("UV_SHOW_RESOLUTION")
+        .arg("--")
+        .arg("pytest")
+        .arg("--version")
+        .env("UV_TOOL_DIR", tool_dir.as_os_str())
+        .env("XDG_BIN_HOME", bin_dir.as_os_str()), @r###"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+    pytest 8.1.1
+
+    ----- stderr -----
+    warning: `uv tool run` is experimental and may change without warning
+    Installed [N] packages in [TIME]
+    "###);
+
+    // Subsequent runs are quiet.
     uv_snapshot!(context.filters(), context.tool_run()
         .env_remove("UV_SHOW_RESOLUTION")
         .arg("--")
